@@ -87,7 +87,14 @@ rm core*
 
 cd ../qrender/; make clean
 rm -rf Makefile *~ .obj .ui .moc 
-rm core*
+rm core* ffmpeg ffmpeg-export-snapshot.tar ffmpeg
+
+ffmpegDir=`ls -d ffmpeg-* 2>/dev/null`
+if [ "$ffmpegDir" != "" ]; then
+  if [ -d "$ffmpegDir" ]; then 
+    rm -rf "$ffmpegDir"
+  fi
+fi
 
 cd ..
 sourceFiles=`cat \`find . -name "*.cpp"\` | wc -l`
