@@ -41,22 +41,31 @@
 
 #include <qdatetime.h>
 
-#define CACHE_DB_FILE      "cach_db.xml"
+#define CACHE_DB_FILE      "cache_db.xml"
 #define IMAGE_DB_FILE      "image_db.xml"
 #define VIRTUAL_DB_FILE    "virtual_db.xml"
+#define VIMAGE_DB_FILE     "virtual_image_db.xml"
 #define CACHE_DOCTYPE      ""
 
 // Deines for the cache xml file
 #define CACHE              "CacheThumbs"
 #define CACHE_TAG_SOURCE   "Source"
+#define CACHE_TAG_IMAGE    "Image"
+#define CACHE_HASH_VALUE   "Hash"
 #define CACHE_NR_OF_THUMBS "NrOfThumbs"
 #define CACHE_FILE_SIZE    "FileSize"
 #define CACHE_RATING       "Rating"
 #define CACHE_VIRTUAL      "VirtualFolders"
+#define CACHE_COMMENT      "Comment"
+#define CACHE_ORIENTATION  "Orientation"
+#define CACHE_ROTATE       "Rotate"
+#define CACHE_DIMENSION    "Dimension"
 #define CACHE_CREATED      "DateCreated"
 #define CACHE_LENGTH       "VideoLength"
 #define CACHE_FILE_NAME    "FileName"
 #define CACHE_LAST_USED    "DateLastUsed"
+#define CACHE_DIMENSION    "Dimension"
+#define CACHE_IMAGE_INFO   "ImageInfo"
 
 // Defines for Virtual Folder
 #define VIRTUAL            "VirtualFolder"
@@ -69,7 +78,7 @@
 
 class QDomElement;
 #include "qplayer/mediascanner.h"
-
+#include "../addons/jhead/libjhead/interface.h"
 
 namespace Cache
 {
@@ -79,30 +88,55 @@ class Thumbs
 public:
   class Entry {
   public:
-    Entry ( Thumbs * );
-    bool readXml  ( QDomElement * );
-    bool writeXml ( QDomElement * );
+             Entry ( Thumbs * );
+    virtual ~Entry ( );
+    virtual bool readXml    ( QDomElement * );
+    virtual bool writeXml   ( QDomElement * );
 
-    void saveImages ( ); // store images to cache
-    void loadImages ( ); // load images from cache
-    void freeImages ( ); // frees the memory 
-    void scanImages ( QObject *p=NULL ); // scans the video file
+    virtual void saveImages ( ); // store images to cache
+    virtual bool loadImages ( ); // load images from cache
+    virtual void freeImages ( ); // frees the memory 
+    virtual void scanImages ( QObject *p=NULL ); // scans the video file
+    virtual QWMatrix *getMatrix ( );
 
     unsigned long long iHashValue;
     bool     bSourceExists; // If the file is not reachable ( removable storage or deleted )
     uint     iScanStatus;   // 0=undef, 1=scanning, 2=scanning done.
     QString  qsFileName;
-    QString  qsLength;  // "00:00:00"
-    uint     iFileSize; // 1234 in bytes
+    QString  qsLength;      // "00:00:00"
+    uint     iFileSize;     // 1234 in bytes
     QImage **arrayOfThumbs;
     uint     iNumberOfThumbs;
     uint     iStarRating;
+    QString  qsComment;     // User provided commant ( to be used as subtitle )
     QStringList listVirtualFolders;
 
+    bool      bStoreData;   // Should this record be kept or removed from the cache.
     QDateTime dateCreated;  // obtained from meta data or file creation date
     QDateTime dateLastUsed; // to eventually purge from the cache
     Thumbs   *pCache;
   };
+  class ImageEntry : public Entry  {
+  public:
+             ImageEntry     ( Thumbs * );
+    virtual ~ImageEntry     ( );
+    virtual bool readXml    ( QDomElement * );
+    virtual bool writeXml   ( QDomElement * );
+
+    virtual void saveImages ( ); // store images to cache
+    virtual bool loadImages ( ); // load images from cache
+    virtual void scanImages ( QObject *p=NULL ); // scans the video file
+    virtual QWMatrix *getMatrix ( );
+    virtual void initMatrix     ( );
+
+    QString   qsDimension; // The width x height
+    QString   qsImageInfo; // All info returned by jhead
+    int       iOrientation;// exif information
+    float     fRotate;     // Manually set by user if != 0.0f
+    bool      bSaveImage;  // Set to false if the image size is < 641 x 481 or if Exif preview exists
+    QWMatrix *pMatrix;     // Transformation-matrix which hold rotate, flip info etc.
+  };
+
   class VirtualFolder {
   public:
     class VFile {
@@ -116,6 +150,7 @@ public:
     ~VirtualFolder ( );
     bool readXml   ( QDomElement * );
     bool writeXml  ( QDomElement * );
+    void append    ( ImageEntry  * );
     void append    ( Entry * );
     void clear     ( );
     uint count     ( );
@@ -144,38 +179,55 @@ public:
   ~Thumbs ( );
 
   void clearCache         ( );
+  void clearImages        ( );
   void clearVirtualFolder ( );
   bool saveCacheDB        ( );
-  bool saveVirtualFolder  ( );
+  bool saveImageDB        ( );
+  bool saveVirtualFolder  ( bool b=false );
 
-  Entry *find     ( QString & );
-  Entry *find     ( unsigned long long );
-  Entry *append   ( QString &, QString q=QString::null, uint i=10,  QImage **pp=NULL );
-  Entry *append   ( QString &, QObject *, uint i=10 );
+  Entry *find   ( QString &, bool b=false );
+  Entry *find   ( unsigned long long, bool b=false );
+  Entry *append ( QString &, QString q=QString::null, uint i=10,  QImage **pp=NULL );
+  Entry *append ( QString &, QObject *, uint  i=10 );
+  Entry *append ( QString &, QImage  * );
 
-  unsigned int   addVirtualFolder    (  QString &   );
-  void           deleteVirtualFolder (  QString &   );
-  void           deleteVirtualFolder ( unsigned int );
-  VirtualFolder *findVirtualFolder   ( unsigned int );
-  VirtualFolder *findVirtualFolder   (  QString &   );
-  QValueList<VirtualFolder *> &getVirtualFolders  ( );
+  unsigned int   addVirtualFolder    (  QString &,   bool b=false );
+  void           deleteVirtualFolder (  QString &,   bool b=false );
+  void           deleteVirtualFolder ( unsigned int, bool b=false );
+  VirtualFolder *findVirtualFolder   ( unsigned int, bool b=false );
+  VirtualFolder *findVirtualFolder   (  QString &,   bool b=false );
+  QValueList<VirtualFolder *> &getVirtualFolders  (  bool b=false );
 
   unsigned long long hashFromFile ( QString & );
-  
-  QValueList<Entry *> getThumbsByStar  ( uint );
+
+  QValueList<Entry *> getThumbsByStar  ( uint, bool b=false );
   QValueList<Entry *> getScannedThumbs ( );
 
+  jhead::JHead *plugin   ( );
 private:
-  bool loadCacheDB       ( ); // Load cache_db.xml file
+  bool loadPlugin        ( ); // Loading libjhead
+  void unloadPlugin      ( ); // unloading libjhead
+
+  bool loadCacheDB       ( );      // Load cache_db.xml file
+  bool loadImageDB       ( );      // Load image_db.xml file
+  bool loadVirtualFolder ( bool ); // Load virtual_db.xml or vimage_db.xml file
   void cleanCacheDB      ( ); // After a set amount of time the cache is freed of images based on dateLastUsed
-  bool loadVirtualFolder ( );
+  void cleanImageDB      ( ); // After a set amount of time the cache is freed of images based on dateLastUsed
   void freeImages        ( ); // to free some space after closing dialog
-  QString getCachePath   ( QChar   );
+  QString getCachePath   ( QString );
+  bool copyOver          ( QString &, QString & );
 
   unsigned long long SDBMHash ( QString & );
 
   QValueList<Entry *>         m_listOfThumbs;
+  QValueList<ImageEntry *>    m_listOfImages;
   QValueList<VirtualFolder *> m_listOfVirtualFolders;
+  QValueList<VirtualFolder *> m_listOfImageFolders;
+
+  // For the exif information, we'll store the plugin information here.
+  void           *m_pLibrary;
+  destroyJHead_t *m_pDestroyFunction;
+  jhead::JHead   *m_pPlugin;
 };
 
 }
