@@ -152,7 +152,7 @@ void DialogButton::initMe ( ButtonObject *pButton, MenuPreview *pView )
 	pMenuObject = m_pClonedButton->getSelected ( 0 );
 	bChecked    = false;
 	if ( pMenuObject )
-	  bChecked  = ( ( pMenuObject->objectType ( ) == MASK_OBJECT ) || 
+	  bChecked  = ( ( pMenuObject->objectType ( ) == MASK_OBJECT ) ||
 			( pMenuObject->objectType ( ) == TEXT_OBJECT ) ); // Text Objects are kind o a mask
 	m_pRadioSelectedMask ->setChecked (  bChecked ); 
 	m_pRadioSelectedFrame->setChecked ( !bChecked ); 
@@ -440,7 +440,7 @@ void DialogButton::initSystem ( MenuPreview *pMenuPreview, ButtonObject *pButton
     iItem = qsTemp.toInt ( &bOkay );
     if ( bOkay ) {
       iItem -= 64;
-      m_pComboSubtitles->setCurrentItem ( iItem );
+      m_pComboSubtitles->setCurrentItem ( iItem+1 );
     }
   }
   rx.setPattern ( "angle=.*;" );
@@ -1173,7 +1173,7 @@ void DialogButton::storeColorsInMenu ( )
   DVDMenu *pDVDMenu = Global::pApp->getCurrentSubMenu ( );
   if ( pDVDMenu ) {
     QValueList <ButtonObject *> listButtons = pDVDMenu->getButtons();
-    
+
     for  ( t=0 ;t<MAX_MASK_COLORS; t++ ) {
       if ( m_pgcColors[t] != m_pgcColorsOrig[t] ) {
 	// Found a new color
@@ -1201,7 +1201,7 @@ void DialogButton::storeColorsInMenu ( )
   }
 }
 
-void DialogButton::slotCancel()
+void DialogButton::slotCancel ( )
 {
   // This function handles only the case of the cancelation of the Button creation.
   // I.e. the user just created the Button and decides to cancel out.
@@ -1211,10 +1211,10 @@ void DialogButton::slotCancel()
     m_pButtonObject->deleteMasks  ( );
     m_pButtonObject->slotUnbutton ( );
   }
-
   // Free memory ...
   m_pClonedButton->removeSelected    ( (uint)0 );
   m_pClonedButton->removeHighlighted ( (uint)0 );
+
   for  ( uint t=0; t<2; t++ ) {
     if ( m_pHighlightedMask[t] )
       delete m_pHighlightedMask[t];
