@@ -393,7 +393,7 @@ void DialogCreateTemplate::slotCreateTemplate ( )
 
     if ( qsTemplatePackageFileName.isEmpty () )
       return;
-    
+
     QWidget *pInstallTab = m_pTabWidget->page ( 2 );
     m_pTabWidget->setTabEnabled      ( pInstallTab, true );
     m_pTabWidget->setCurrentPage     ( 2 );
@@ -401,7 +401,7 @@ void DialogCreateTemplate::slotCreateTemplate ( )
     return;
   }
   // User clicked on the [Define DropZones >>>] button.
-  
+
   // first verify if all required data was entered.
   QLineEdit *arrayRequiredInfo[] = { m_pEditAuthor, m_pEditVersion, m_pEditHeader, m_pEditFileName };
   for ( t=0;t<4;t++) {
@@ -454,7 +454,7 @@ void DialogCreateTemplate::slotInstall ( )
 
   // Okay at this point I should have all required information ... lets get started ...
   QString qsPrefixDir;
-  QString qsInstallDir = PREFIX_DIRECTORY"/share/qdvdauthor/";
+  QString qsInstallDir = Global::qsSystemPath + "/share/qdvdauthor/";
   if ( m_pRadioLocally->isChecked ( ) )
     qsInstallDir = QDir::homeDirPath ( ) + "/.qdvdauthor/";
   qsPrefixDir = qsInstallDir;
@@ -537,16 +537,16 @@ void DialogCreateTemplate::installToSystem ( QString &qsCommand, bool bInstallLo
   connect( m_pNewProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadFromProcess ( ) ) );
   connect( m_pNewProcess, SIGNAL ( readyReadStderr ( ) ), this, SLOT ( slotReadFromProcess ( ) ) );
   connect( m_pNewProcess, SIGNAL ( processExited   ( ) ), this, SLOT ( slotProcessExited   ( ) ) );
-  
+
   if ( ! bInstallLocally ) {
     // the next check is to see if we can find kdesu
     QString qsGuiSU = findGuiSU ( );
     if ( qsGuiSU.isEmpty ( ) ) {
       MessageBox::information (NULL, tr ( "Could not find kdesu, xsu, or gnomesu" ),
         tr ( "Without kdesu, xsu, or gnomesu I can not istall them templates in %1/share/qdvdauthor/.\n").
-	arg ( PREFIX_DIRECTORY ), QMessageBox::Ok ,  QMessageBox::NoButton);
+	arg ( Global::qsSystemPath ), QMessageBox::Ok ,  QMessageBox::NoButton);
       return;
-    }  
+    }
     if (qsGuiSU == QString ("kdesu"))	{
       m_pNewProcess->addArgument ("kdesu");
       m_pNewProcess->addArgument ("-n");
@@ -630,7 +630,7 @@ QString DialogCreateTemplate::createTemplate ( )
     return qsTemplatePath;
   if ( ! createBackground  ( qsTemplatePath ) )
     return qsTemplatePath;
-  
+
   // These two functions are for convenience ...
   //  createIndexXml ( );
   //  createWebHtml  ( );
@@ -668,7 +668,7 @@ bool DialogCreateTemplate::createTemplateXml ( QString &qsTemplatePath )
   QString qsDescription = m_pTextDesc->text ( );
   qsDescription = qsDescription.replace ( "<", "&lt;" );
   qsDescription = qsDescription.replace ( ">", "&gt;" );
-  
+
   qsXml  = "<!DOCTYPE QDVDAuthor>\n";
   qsXml += "<QDVDTemplate TemplateName=\"" + m_pEditFileName->text ( ) + "\" "TEMPLATE_VERSION"=\"" + QString ( "%1" ).arg (TEMPLATE_VERSION_NUMBER ) + "\" >\n";
   qsXml += " <"TEMPLATE_VERSION">"         + m_pEditVersion->text  ( ) + "</"TEMPLATE_VERSION">\n";
@@ -707,7 +707,18 @@ bool DialogCreateTemplate::createTemplateXml ( QString &qsTemplatePath )
   QDomElement  menuElement = xmlDoc.createElement( "RemoveMe" );
 
   xmlDoc.appendChild ( menuElement );
+
+  CDVDMenuInterface *pMenuInterface = m_pDVDMenu->getInterface ( );
+  int iTitlesetNr  = pMenuInterface->iTitleset;
+  int iMenuNr      = pMenuInterface->iMenu;
+  pMenuInterface->iTitleset = -1;
+  pMenuInterface->iMenu     = -1;
+
   m_pDVDMenu->writeProjectFile ( menuElement );
+
+  pMenuInterface->iTitleset = iTitlesetNr;
+  pMenuInterface->iMenu     = iMenuNr;
+
   // At this point we shoul have the XML as Standard ...
   qsMenuXml = xmlDoc.toString ( );
 
@@ -722,7 +733,7 @@ bool DialogCreateTemplate::createTemplateXml ( QString &qsTemplatePath )
   // between <MenuName> and </MenuName>
   rx.setPattern ( "<MenuName>.*</MenuName>" );
   qsMenuXml.replace ( rx, "<MenuName>"+m_pEditFileName->text ( )+"</MenuName>" );
-  
+
   // Next we change the background file name
   handleMenuBackground ( qsMenuXml );
 
@@ -796,7 +807,7 @@ void DialogCreateTemplate::handleMenuAudio ( QString &qsMenuXml, QString &qsTemp
 	iPos += rx.matchedLength ( );
       }
     }
-    
+
     // The second step is to copy the files over and create the XML ...
     for ( t=0;t<(int)listSoundFiles.count ( ); t++ ) {
 // printf ( "%s::%s::%d - [%d] = <%s>\n", __FILE__, __FUNCTION__, __LINE__, t, listSoundFiles [t].ascii ( ) );
