@@ -141,11 +141,7 @@ void DialogImages::slotEditGroup ( )
     pSlideshow->validFilterNames = theDialog.filterList ( );
     pSlideshow->yres             =(theDialog.m_pComboFormat->currentItem ( ) == 0) ? 480 : 576;
     pSlideshow->xres             = 720;
-
-    bool bChecked = theDialog.m_pRadioImgBkgImg->isChecked ( );
-    QValueList<CXmlSlideshow::filter_struct *>::iterator it = pSlideshow->m_listFilter.begin ( );
-    while ( it != pSlideshow->m_listFilter.end ( ) )
-      (*it++)->bImgBackgroundImg = bChecked;
+    pSlideshow->setImgBkgImg ( theDialog.m_pRadioImgBkgImg->isChecked ( ) );
   }
 }
 
@@ -1019,8 +1015,10 @@ void DialogImages::accept ( )
         Cache::Thumbs::ImageEntry *pImgCache;
         tempSlideshow = *pSlideshow;
         pSlideshow->clearObjects ( );
+        pSlideshow->audio_list       = tempSlideshow.audio_list;
+        pSlideshow->validFilterNames = tempSlideshow.validFilterNames;
         while ( pGroupItem )  {
-          if ( isImageDialog ( pGroupItem->pCache->qsFileName ) )  {
+          if  ( isImageDialog ( pGroupItem->pCache->qsFileName ) )  {
             pXmlImg       = pSlideshow->addImg ( );
             pXmlImg->src  = pGroupItem->pCache->qsFileName;
             pXmlImg->text = pGroupItem->text ( 0 );
