@@ -6,6 +6,11 @@
 ** developement of dvdauthor, which is at the moment in version 0.67.
 ** Future versions of dvdauthort might need changes to this file.
 **
+**   Created : 
+**        by : Varol Okan 
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 *****************************************************************************/
 
 #include <stdlib.h>
@@ -91,7 +96,8 @@ DialogMan::DialogMan( QStringList &listOfCommands, QWidget* parent, const char*
 
 		// here we put the man pages into a text file and read tis file into the textEdit.
 		command = QString("man %1 2>/dev/null | col -b > /tmp/%2.man").arg(listOfCommands[t]).arg(listOfCommands[t]);
-		system ((const char *)command);
+		if ( system ((const char *)command) == -1 )
+			return;
 		command = QString("/tmp/%1.man").arg(listOfCommands[t]);
 		QFileInfo fileInfo(command);
 		// Check to see if we found a man page for this command ...
@@ -150,7 +156,9 @@ void DialogMan::slotFind ()
 	// This function will take the entered text and search for it in the Man page currently active ...
 	if (m_listTextEdit.count() < 1)
 		return;
-	QTextEdit *pTextEdit = m_listTextEdit[0];
+	
+	int iIndex = tabWidget2->currentPageIndex ( );
+	QTextEdit *pTextEdit = m_listTextEdit[ iIndex < (int)m_listTextEdit.count ( ) ? iIndex : 0 ];
 	bool bFound = pTextEdit->find (m_pEditFind->text(), false, false);
 	if (!bFound)	{
 		// Set cursor back to the top ...
