@@ -117,7 +117,9 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
   // Called when handling the background of a menu (Image background or MovieBackground.)
   if ( ! pMenu )
     return;
-  if ( (pMenu->getInterface()->qsMovieFileName.isNull()) && (pMenu->getInterface()->qsBackgroundFileName.isNull ( ) ) )
+
+  CDVDMenuInterface *pInterface = pMenu->getInterface ( );
+  if ( ( pInterface->qsMovieFileName.isNull ( ) ) && ( pInterface->qsBackgroundFileName.isNull ( ) ) )
     return;
 
   QFileInfo fileInfo;
@@ -126,9 +128,9 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
 
   m_pDVDMenu = pMenu;
   qsFormat = QString ("hh:mm:ss.zzz");
-  QTime endingTime = pMenu->getInterface()->timeOffset.addMSecs(-pMenu->getInterface()->timeDuration.msecsTo(QTime()));
-  m_pEditStarting2->setText (pMenu->getInterface()->timeOffset.toString(qsFormat));
-  m_pEditEnding2  ->setText (endingTime.toString (qsFormat));
+  QTime endingTime = pInterface->timeOffset.addMSecs ( -pInterface->timeDuration.msecsTo ( QTime ( ) ) );
+  m_pEditStarting2->setText ( pInterface->timeOffset.toString ( qsFormat ) );
+  m_pEditEnding2  ->setText ( endingTime.toString ( qsFormat ) );
 
   // Okay coming from the MovieObject we need only the Geometry - tab
   QWidget *pTab = m_pTabWidget->page (TRANSCODING_TAB);
@@ -161,43 +163,49 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
   delete textLabel2_2;
   m_pButtonCK->setText (tr("Change Size ..."));
   m_pButtonCK->setSizePolicy ( policy );
-  disconnect ( m_pButtonCK, SIGNAL(clicked ()), this, SLOT ( slotBrowseColorKey ( ) ) );
-  connect    ( m_pButtonCK, SIGNAL(clicked ()), this, SLOT ( slotSizeDialog     ( ) ) );
+  disconnect ( m_pButtonCK,  SIGNAL ( clicked ( ) ), this, SLOT ( slotBrowseColorKey ( ) ) );
+  connect    ( m_pButtonCK,  SIGNAL ( clicked ( ) ), this, SLOT ( slotSizeDialog     ( ) ) );
+  connect    ( m_pCheckLoop, SIGNAL ( clicked ( ) ), this, SLOT ( slotMenuLoop       ( ) ) );
+
+  if ( pInterface->qsPost == "Loop" )  {
+    m_pCheckLoop->setChecked ( true );
+    slotMenuLoop ( );
+  }
   groupBox8->setTitle ("");
   m_pCheckSameAsMenuLength->hide ( );
   m_pButtonLoop->hide ( );
 
-  if (  (  ! pMenu->getInterface ( )->qsPause.isEmpty ( ) ) && 
-        (    pMenu->getInterface ( )->qsPause !=  "inf" ) ) 
-    iPause = pMenu->getInterface ( )->qsPause.toInt   ( );
+  if (  (  ! pInterface->qsPause.isEmpty ( ) ) && 
+        (    pInterface->qsPause !=  "inf" ) ) 
+    iPause = pInterface->qsPause.toInt   ( );
 
   m_pLabelTitle->setText       ( "SubMenu:"       );
-  m_pSpinBoxTitle->setValue    ( pMenu->getInterface ( )->iMenu     );
-  m_pSpinBoxTitleset->setValue ( pMenu->getInterface ( )->iTitleset );
+  m_pSpinBoxTitle->setValue    ( pInterface->iMenu     );
+  m_pSpinBoxTitleset->setValue ( pInterface->iTitleset );
   m_pSpinBoxPause->setValue    ( iPause );
   // The VMGM Must stay in Titleset 0 !!!
-  if ( ! pMenu->getInterface ( )->bIsSubMenu ) {
+  if ( ! pInterface->bIsSubMenu ) {
     m_pSpinBoxTitle->setEnabled    ( false );
     m_pSpinBoxTitleset->setEnabled ( false );
   }
   // Here we handle a MovieBackground ...
-  if ( ! pMenu->getInterface()->qsMovieFileName.isEmpty ( ) )  {
+  if ( ! pInterface->qsMovieFileName.isEmpty ( ) )  {
     initMediaInterface ( pMenu );
-    m_pTabWidget->setTabLabel ( pTab, "MovieBackground" );
+    m_pTabWidget->setTabLabel   ( pTab, "MovieBackground" );
     m_pButtonThumbnail->setText ( tr ( "Set Background" ) );
     //    m_pTabWidget->setCurrentPage ( 1 );
   }
   else	{	// Here we handle a ImageBackground ...
-    if ( ! pMenu->getInterface()->qsBackgroundFileName.isEmpty ())	{
+    if ( ! pInterface->qsBackgroundFileName.isEmpty ( ) )  {
       QPixmap thePixmap;
-      QImage theImage ( pMenu->getInterface()->qsBackgroundFileName );
+      QImage theImage ( pInterface->qsBackgroundFileName );
       theImage = theImage.smoothScale (275, 275, QImage::ScaleFree);
       thePixmap.convertFromImage (theImage);
       m_pMediaPreview->setPixmap (thePixmap);
     }
     m_pMediaPreview->setFixedSize (275, 275);
-    m_pEditStarting2  ->setEnabled  ( false );
-    fileInfo.setFile ( pMenu->getInterface()->qsBackgroundFileName );
+    m_pEditStarting2->setEnabled  ( false );
+    fileInfo.setFile ( pInterface->qsBackgroundFileName );
     m_pTextTitle->setText (tr ("ImageBackground : %1").arg(fileInfo.fileName()));
     setCaption ( fileInfo.fileName () );
     m_pTabWidget->setTabLabel (pTab, "ImageBackground");
@@ -216,10 +224,10 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
   m_pComboPostCommand->clear ( );
   m_pComboPostCommand->insertItem ( " jump vmgm menu 1; " );
 
-  if ( ! pMenu->getInterface ( )->qsPre.isEmpty  ( ) )
-    m_pComboPreCommand->setCurrentText ( pMenu->getInterface  ( )->qsPre  );
-  if ( ! pMenu->getInterface ( )->qsPost.isEmpty ( ) )
-    m_pComboPostCommand->setCurrentText ( pMenu->getInterface ( )->qsPost );
+  if ( ! pInterface->qsPre.isEmpty  ( ) )
+    m_pComboPreCommand->setCurrentText  ( pInterface->qsPre  );
+  if ( ! pInterface->qsPost.isEmpty ( ) )
+    m_pComboPostCommand->setCurrentText ( pInterface->qsPost );
 
   // These controls are not used ...
   delete groupBox2;
@@ -265,6 +273,7 @@ void DialogMovie::initMe ( SourceFileEntry *pSourceFileEntry )
   delete m_pSliderVolume;
   delete m_pLabelCurrentPos;
   delete m_pFrameControl;
+  m_pCheckLoop->hide ( );
 
   connect (m_pComboVideoOut,        SIGNAL( activated(const QString &)), this, SLOT (slotVideoOutChanged(const QString &)));
   connect (m_pComboVideoResolution, SIGNAL( activated(const QString &)), this, SLOT (slotVideoResolutionChanged(const QString &)));
@@ -314,6 +323,7 @@ void DialogMovie::initMe ( SourceFileInfo *pInfo, const void *pExistingMediaEngi
     m_pEditAdd->setText (qsReturn);
   }
   m_pEditEnding1->setText(qsReturn);
+  m_pCheckLoop->hide ( );
 
   // Here we copy the infos over ...
   m_sourceFileInfo = *pInfo;
@@ -362,14 +372,17 @@ void DialogMovie::initMe ( SourceFileInfo *pInfo, const void *pExistingMediaEngi
   pLayout->addWidget( m_pStartStopControl, 0, 0 );
 
   if ( m_sourceFileInfo.pTranscodeInterface )	{
-    if ( m_sourceFileInfo.pTranscodeInterface->iEndingAt == 0 )
-      m_sourceFileInfo.pTranscodeInterface->iEndingAt = m_iMovieLength;
-    QString qsFormat = QString ("hh:mm:ss.zzz");
+    if ( m_sourceFileInfo.pTranscodeInterface->iEndingAt == 0 ) 
+         m_sourceFileInfo.pTranscodeInterface->iEndingAt = m_iMovieLength;
+    int  iMovieLength = m_sourceFileInfo.pTranscodeInterface->iEndingAt;
+    if ( iMovieLength > m_iMovieLength )
+         iMovieLength = m_iMovieLength;
+    QString  qsFormat = QString ("hh:mm:ss.zzz");
     QTime endingTime, startingTime;
     startingTime = startingTime.addMSecs ( m_sourceFileInfo.pTranscodeInterface->iStartingAt );
-    endingTime   = endingTime.addMSecs   ( m_sourceFileInfo.pTranscodeInterface->iEndingAt   );
-    m_pEditStarting1->setText (startingTime.toString(qsFormat));
-    m_pEditEnding1  ->setText (endingTime.toString  (qsFormat));
+    endingTime   = endingTime.addMSecs   ( iMovieLength  );
+    m_pEditStarting1->setText ( startingTime.toString ( qsFormat ) );
+    m_pEditEnding1  ->setText ( endingTime.toString   ( qsFormat ) );
   }
 
   m_pLabelVideoFormat->setText (QString ("%1(%2) %3Hz").arg( pInfo->qsVideoFormat ).arg ( pInfo->qsResolution ).arg ( pInfo->qsFPS ) );
@@ -477,6 +490,7 @@ void DialogMovie::initMe ( MovieObject *pMovieObject )
         endingTime = clipTime;
 
   m_pEditEnding2->setText ( endingTime.toString  ( qsFormat ) );
+  m_pCheckLoop->hide ( );
 
   m_rectGeometry = pMovieObject->rect     ( );
   m_qsFileName   = pMovieObject->fileName ( );
@@ -530,9 +544,9 @@ void DialogMovie::initMediaInterface ( DVDMenu *pDVDMenu )
     iThumbnailSize = pDVDMenu->getDVDAuthor()->getDragNDropContainer()->sizeThumbnail.width();
     if (m_qsFileName.isEmpty() || m_qsFileName.isNull() )	{
       if (pDVDMenu->getInterface()->qsMovieFileName.isNull())
-	m_qsFileName = pDVDMenu->getInterface()->qsBackgroundFileName;
+        m_qsFileName = pDVDMenu->getInterface ( )->qsBackgroundFileName;
       else
-	m_qsFileName = pDVDMenu->getInterface()->qsMovieFileName;
+        m_qsFileName = pDVDMenu->getInterface ( )->qsMovieFileName;
     }
     fileInfo.setFile (m_qsFileName);
     qsBackgroundName = QString (" : %1 <%2>").arg(fileInfo.fileName()).arg(pDVDMenu->getInterface()->timeDuration.toString(qsFormat));
@@ -634,28 +648,28 @@ void DialogMovie::initAudioTab ( SourceFileInfo *pInfo, DVDMenu *pMenu )
     for ( t=0; t<MAX_SUBTITLES; t++ ) {
       pSubtitle = pInfo->arraySubtitles[t];
       if ( pSubtitle ) {
-	// #, code, Language, file
-	new QListViewItem ( m_pListViewSubtitles, QString ( "%1" ).arg ( pSubtitle->m_iSubtitleNumber ), pSubtitle->m_qsIso639, theUtils.iso639 ( pSubtitle->m_qsIso639, false ), QString ( "%1" ).arg ( pSubtitle->m_listOfSubtitles.count ( ) ) );
+        // #, code, Language, file
+        new QListViewItem ( m_pListViewSubtitles, QString ( "%1" ).arg ( pSubtitle->m_iSubtitleNumber ), pSubtitle->m_qsIso639, theUtils.iso639 ( pSubtitle->m_qsIso639, false ), QString ( "%1" ).arg ( pSubtitle->m_listOfSubtitles.count ( ) ) );
       }
     }
 
     for ( t=0; t<MAX_AUDIO; t++ ) {
       pAudio = pInfo->arrayAudio[t];
       if ( pAudio ) {
-	// #, code, Language, file
-	new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber ), pAudio->qsIso639, theUtils.iso639 ( pAudio->qsIso639, false ), pAudio->qsFileName );
+        // #, code, Language, file
+        new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber ), pAudio->qsIso639, theUtils.iso639 ( pAudio->qsIso639, false ), pAudio->qsFileName );
       }
     }
 
   }
   else if ( pMenu ) {
     CDVDMenuInterface *pInterface = pMenu->getInterface  ( );
-	Utils theUtils;
+    Utils theUtils;
     for ( t=0; t<(int)pInterface->listSoundEntries.count ( ); t++ ) {
       Audio *pAudio = pInterface->listSoundEntries[t];
-	  QString qsCode = theUtils.iso639 ( pAudio->qsIso639, false );
+      QString qsCode = theUtils.iso639 ( pAudio->qsIso639, false );
       if ( pAudio ) {
-	    new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber), pAudio->qsIso639, qsCode, pAudio->qsFileName );
+        new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber), pAudio->qsIso639, qsCode, pAudio->qsFileName );
       }
     }
     m_pFrameSubtitles->hide ( );
@@ -726,6 +740,8 @@ void DialogMovie::slotAddAudio ( )
   if ( listFiles.size ( ) < 1 )
     return;
   QString qsSelFileName  = listFiles[0];
+  QFileInfo fileInfo ( qsSelFileName );
+  Global::qsCurrentPath = fileInfo.absFilePath ( );
 
   if ( m_pDVDMenu ) {
     QDVDAuthor *pDVDAuthor = m_pDVDMenu->getDVDAuthor ( );
@@ -916,7 +932,7 @@ void DialogMovie::slotDeleteAudio ( )
 	break;
       }
     }
-    
+
     // remove from m_pParentSourceFileEntry if this has been the last reference to this audio track.
     bFound = false;
     if ( m_pParentSourceFileEntry ) {
@@ -945,7 +961,7 @@ void DialogMovie::slotAddSubtitle ( )
   QString qsLang ( "English" );
   // First we import the srt - file.
   Import::Srt theImporter;
-  
+
   if ( ! theImporter.import ( ) )
     return;
 
@@ -958,9 +974,15 @@ void DialogMovie::slotAddSubtitle ( )
   if ( ! subtitleDialog ( iValue, qsLang ) )
     return;
 
-  if ( ! sanityCheckSubtitleTrack ( iValue ) )
+  if ( ! sanityCheckSubtitleTrack ( iValue, qsLang ) )
     return;
 
+  QString qsFileName = theImporter.getFileName ( );
+  if ( qsFileName.length ( )  >  1 )  {
+    QFileInfo fileInfo   ( qsFileName );
+    Global::qsCurrentPath = fileInfo.absFilePath ( );
+  }
+
   if ( m_sourceFileInfo.arraySubtitles [ iValue ] ) {
     QFileInfo fileInfo ( m_sourceFileInfo.qsFileName );
     // the subtitle already exists in the sourcefileinfo.
@@ -995,7 +1017,7 @@ void DialogMovie::slotEditSubtitle ( )
   if ( ! subtitleDialog ( iNumber, qsLanguage ) ) // iNumber might be changed here.
     return;
   if ( t != iNumber ) {
-    if ( ! sanityCheckSubtitleTrack ( iNumber ) )
+    if ( ! sanityCheckSubtitleTrack ( iNumber, qsLanguage ) )
       return;
 
     if ( m_sourceFileInfo.arraySubtitles [ iNumber ] ) {
@@ -1118,12 +1140,14 @@ void DialogMovie::timerEvent ( QTimerEvent *pEvent )
   uiDialogMovie::timerEvent ( pEvent );
 }
 
-bool DialogMovie::sanityCheckSubtitleTrack ( int &iSubtitle )
+bool DialogMovie::sanityCheckSubtitleTrack ( int &iSubtitle, QString &qsLanguage )
 {
   // This function will check the sourceFileEntry and all attached 
   // SourceFileInfos if the ubtitle track is aready in use.
   // If not this function will return and leave iSubtitle unchanged.
   // If it is in use the subtitle number will be changed.
+  Utils theUtils;
+  QString qsIso639 = theUtils.iso639 ( qsLanguage, true );
   SourceFileEntry *pEntry = m_pParentSourceFileEntry;
   SourceFileInfo  *pInfo;
   int t, iNewSubtitle;
@@ -1131,7 +1155,7 @@ bool DialogMovie::sanityCheckSubtitleTrack ( int &iSubtitle )
   if ( pEntry ) {
     if ( pEntry->arraySubtitleEntries[ iSubtitle ].m_iSubtitleNumber == -1 )
       return true;  // All is well
-    // The next step is to ensure that the current SourceFileInfo is 
+    // The next step is to ensure that the current SourceFileInfo is
     // not the only one using this Subtitle
     for ( t=0; t<(int)pEntry->listFileInfos.count ( ); t++ ) {
       pInfo = pEntry->listFileInfos[t];
@@ -1145,17 +1169,26 @@ bool DialogMovie::sanityCheckSubtitleTrack ( int &iSubtitle )
     if ( !bFound )
       return true; // Okay the current subtitle is only used by the current SourceFileInfo ... No harm.
 
+    // Find a proposed subtitle
     for ( iNewSubtitle=0; iNewSubtitle<MAX_SUBTITLES; iNewSubtitle++ ) {
-      if ( pEntry->arraySubtitleEntries[iNewSubtitle].m_iSubtitleNumber == -1 ) {
-	break;
+      if ( ( pEntry->arraySubtitleEntries[iNewSubtitle].m_qsIso639  == qsIso639 ) ||
+           ( pEntry->arraySubtitleEntries[iNewSubtitle].m_iSubtitleNumber == -1 ) ) {
+        break;
       }
     }
+
+    // In case the subtitle channel is alreay used we want to make sure the languages are the same
+    if ( qsIso639 == pEntry->arraySubtitleEntries[iSubtitle].m_qsIso639 )  {
+      return true;
+    }
     if ( iNewSubtitle>MAX_SUBTITLES-1 ) {
       MessageBox::warning ( this, tr ( "Too many Subtitles." ), tr ( "Too many subtitles for the SourceFileEntry\n%1\nPlease remove a subtitle track first before trying to add a new one." ).arg ( pEntry->qsDisplayName ) );
       return false;
     }
-    if ( MessageBox::question ( this, tr ( "Subtitle track %1 already in use." ).arg ( iSubtitle ), 
-	   tr ( "Subtitle track %1 already in use.\nProposing track %2 instead." ).arg ( iSubtitle ).arg ( iNewSubtitle ),
+
+    QString qsLang = theUtils.iso639 ( pEntry->arraySubtitleEntries[iSubtitle].m_qsIso639, false );
+    if ( MessageBox::question ( this, tr ( "Subtitle track %1 already in use." ).arg ( iSubtitle ),
+	   tr ( "Subtitle track %1 already in use for language [%2].\nProposing track %3 for language [%4] instead." ).arg ( iSubtitle ).arg ( qsLang ).arg ( iNewSubtitle ).arg ( qsLanguage ),
 	   QMessageBox::Ok, QMessageBox::Cancel) == QMessageBox::Ok ) {
       // Okay at this point we can change the subtitle number
       iSubtitle = iNewSubtitle;
@@ -1251,6 +1284,28 @@ void DialogMovie::slotSameAsMenuLength ( )
   }
 }
 
+void DialogMovie::slotMenuLoop ( )
+{
+  // The user wants the menu video to loop.
+  // So we need to
+  if ( m_pCheckLoop->isChecked ( ) )  {
+    // Gray out Pause after and set to '0'
+    m_pSpinBoxPause->setEnabled ( false );
+    m_pSpinBoxPause->setValue   ( 0 );
+    // Gray out Post command and fill in "Loop"
+    m_pComboPostCommand->setEnabled     (  false );
+    m_pComboPostCommand->setCurrentText ( "Loop" );
+  }
+  else  {
+    // Enable Pause after and set to '-1'
+    m_pSpinBoxPause->setEnabled ( true );
+    m_pSpinBoxPause->setValue   (  -1  );
+    // Gray out Post command and fill in "Loop"
+    m_pComboPostCommand->setEnabled     ( true );
+    m_pComboPostCommand->setCurrentText ( " jump vmgm menu 1; " );
+  }
+}
+
 void DialogMovie::slotLoop ( )
 {
   if ( m_pButtonLoop->text ( ) ==  tr ( "Loop" ) )
@@ -1790,7 +1845,7 @@ void DialogMovie::slotSizeDialog ( )
 {
   if ( ! m_pDVDMenu )
     return;
-  m_pDVDMenu->changeSize ();
+  m_pDVDMenu->changeSize ( );
 }
 
 void DialogMovie::slotImportChapter ( )
