@@ -96,6 +96,7 @@ protected slots:
 	virtual void slotCheckStart         ( );
 	virtual void slotCheckEnd           ( );
 	virtual void slotLoop               ( );
+	virtual void slotMenuLoop           ( );
 
 	virtual void slotAddColorKey    ( );
 	virtual void slotDelColorKey    ( );
@@ -122,7 +123,7 @@ private:
 	void addChapter     ( QString &        );
 	void initMediaInterface ( DVDMenu    * );
 	void initAudioTab   ( SourceFileInfo *, DVDMenu *p=NULL );
-	bool sanityCheckSubtitleTrack( int   & );
+	bool sanityCheckSubtitleTrack( int   &, QString & );
 	void addSubtitle    ( QString, int, QValueList<Subtitles::entry *> & );
 	bool subtitleDialog ( int &, QString & );
 	void deleteSubtitle ( int );
