@@ -350,6 +350,11 @@ void DialogSlideshow::slotSelectionChanged ( QListViewItem * )
   QString qsTransitionPath = Global::qsSystemPath + QString ( "/share/qdvdauthor/slideshow/transitions/alpha/" );
   QString qsFilterName     = pItem->text ( );
   QString qsFileName       = qsTransitionPath + qsFilterName + ".jpg";
+
+  QFileInfo fileInfo ( qsFileName );
+  if ( ! fileInfo.exists ( ) )
+    return; // E.g. "Cross Fade"
+
   QImage theImage ( qsFileName );
   theImage = theImage.smoothScale ( m_pLabelPreview->size ( ) );
   QPixmap thePix;
@@ -583,7 +588,7 @@ void DialogSlideshow::slotColor ( )
 void DialogSlideshow::slotAddAudio ( )
 {
   QString qsFilter = "Audio ( " + Global::pApp->getSoundFilter  ( ) + ")";
-  QStringList list = QFileDialog::getOpenFileNames ( qsFilter, Global::qsCurrentPath, this );
+  QStringList list = FilePreviewDialog::getOpenFileNames ( Global::qsCurrentPath, qsFilter, this );
 
   if ( list.count ( ) < 1 )
     return;
