@@ -41,7 +41,7 @@ DialogThumbnail::ThumbnailRequest::ThumbnailRequest ( DialogThumbnail *pDialog,
   pOwnerItem      = pItem;
   pParent         = pDialog;
   iMSecondsOffset = iOffset;
-  qsFileName      = qsFile;    
+  qsFileName      = qsFile;
 }
 
 DialogThumbnail::ThumbnailRequest::~ThumbnailRequest ( )
@@ -51,21 +51,22 @@ DialogThumbnail::ThumbnailRequest::~ThumbnailRequest ( )
 }
 
 bool DialogThumbnail::ThumbnailRequest::response ( )
-{  
+{
   if ( ! pParent )
     return false;
   // Rather then copy data back and forth I simply steal the pointer to the QImage object
   QImage *pTempImage = pImage;
   pImage = NULL;
-  pParent->initWork ( pOwnerItem, pTempImage );
+  pParent->initWork ( pOwnerItem, pTempImage, qsFileName );
 
   return true;
 }
 
-DialogThumbnail::WorkWaiting::WorkWaiting ( QIconViewItem *pViewItem, QImage *pImg )
+DialogThumbnail::WorkWaiting::WorkWaiting ( QIconViewItem *pViewItem, QImage *pImg, QString qsFile )
 {
-  pItem  = pViewItem;
-  pImage = pImg;
+  pItem      = pViewItem;
+  pImage     = pImg;
+  qsFileName = qsFile;
 }
 
 DialogThumbnail::WorkWaiting::~WorkWaiting ( )
@@ -79,6 +80,7 @@ DialogThumbnail::DialogThumbnail ( QDVDAuthor *pDVDAuthor, const char *pName, WF
   : uiDialogThumbnail ( pDVDAuthor, pName, f )
 {
   m_pSourceFileInfo  = NULL;
+  m_pSourceFileEntry = NULL;
   m_iCurrentChapter  = 0;
   m_iThumbnailWidth  = 120;
   m_iThumbnailHeight = 120;
@@ -105,7 +107,116 @@ DialogThumbnail::~DialogThumbnail ( )
 {
   // remove any outstanding requests ...
   MediaCreator::unregisterFromMediaScanner ( this );
-  MediaCreator::unregisterFromMediaScanner ( m_pSourceFileInfo );
+  if ( m_pSourceFileInfo )
+    MediaCreator::unregisterFromMediaScanner ( m_pSourceFileInfo );
+  if ( m_pSourceFileEntry )  {
+    QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+    SourceFileInfo *pInfo;
+    while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
+      pInfo = *it++;
+      if ( ! pInfo )
+        continue;
+      MediaCreator::unregisterFromMediaScanner ( pInfo );
+    }
+  }
+}
+
+bool DialogThumbnail::haveSource ( )
+{
+  return ( m_pSourceFileInfo || m_pSourceFileEntry );
+}
+
+int DialogThumbnail::chapterCount ( )
+{
+  int i=0;
+  if ( m_pSourceFileInfo )
+   i = m_pSourceFileInfo->listChapters.count ( );
+  if ( m_pSourceFileEntry )  {
+    QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+    SourceFileInfo *pInfo;
+    while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
+      pInfo = *it++;
+      if ( ! pInfo )
+        continue;
+      if ( pInfo->listChapters.count  ( ) == 0 )
+           pInfo->listChapters.append ( "00:00:00.000" );
+      i += pInfo->listChapters.count  ( );
+    }
+  }
+
+  return i;
+}
+
+QString DialogThumbnail::chapter ( int iChapterNumber )
+{
+  QString qsChapter ( "00:00:00.000" );
+  if ( m_pSourceFileInfo )  {
+    if ( (int)m_pSourceFileInfo->listChapters.count ( ) > iChapterNumber )
+      qsChapter  =  m_pSourceFileInfo->listChapters     [ iChapterNumber ];
+  }
+  if ( m_pSourceFileEntry )  {
+    int i=0;
+    QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+    SourceFileInfo *pInfo;
+    while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
+      pInfo = *it++;
+      if ( ! pInfo )
+        continue;
+      if ( iChapterNumber < (int)( i + pInfo->listChapters.count ( ) ) )
+           return pInfo->listChapters [ iChapterNumber - i ];
+      i += pInfo->listChapters.count  ( );
+    }
+  }
+  return qsChapter;
+}
+
+SourceFileInfo *DialogThumbnail::getInfoFromChapterNumber ( int iChapterNumber )
+{
+  if ( m_pSourceFileInfo )
+    return m_pSourceFileInfo;
+  if ( m_pSourceFileEntry )  {
+    int i=0;
+    QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+    SourceFileInfo *pInfo;
+    while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
+      pInfo = *it++;
+      if ( ! pInfo )
+        continue;
+      if ( iChapterNumber < (int)( i + pInfo->listChapters.count ( ) ) )
+           return pInfo;
+      i += pInfo->listChapters.count  ( );
+    }
+  }
+  return NULL;
+}
+
+int DialogThumbnail::getChapterNumberFromKey ( QString qsKey )
+{
+  if ( ! m_pSourceFileEntry )
+    return 0;
+
+  // This is to assign the Chapter number to the QIconViewItem
+  QString   qsActionString;
+  QFileInfo fileInfo;
+  int t, i=0;
+
+  QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+  SourceFileInfo *pInfo;
+  while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
+    pInfo = *it++;
+    if ( ! pInfo )
+      continue;
+    fileInfo.setFile ( pInfo->qsFileName );
+
+    for ( t=0; t<(int)pInfo->listChapters.count ( ); t++ )  {
+      // This is a slow comparion but we deal only with a few chapters. Should not be in the thousands.
+      qsActionString = QString ( "jump+-+%1+-+%2+-+%3" ).arg ( m_pSourceFileEntry->qsDisplayName ).arg ( fileInfo.fileName ( ) ).arg ( pInfo->listChapters[t] );
+      if ( qsActionString == qsKey )
+        return i;
+      i++;
+    }
+  }
+  return 0;
 }
 
 void DialogThumbnail::show ( )
@@ -128,18 +239,55 @@ void DialogThumbnail::show ( )
   }
 }
 
+void DialogThumbnail::initSourceFileEntry ( SourceFileEntry *pEntry )
+{
+  m_pListBoxChapters   ->clear ( );
+  m_pIconViewThumbnails->clear ( );
+
+  if ( ! pEntry )
+    return;
+
+  setCaption ( QString ( "Thumbnail Dialog : " ) + pEntry->qsDisplayName );
+  m_pSourceFileInfo  = NULL;
+  m_pSourceFileEntry = pEntry;
+
+  int t;
+  QStringList listChapters;
+  SourceFileInfo *pInfo;
+  QFileInfo fileInfo;
+  QString qsChapter;
+
+  QValueList<SourceFileInfo *>::iterator it = pEntry->listFileInfos.begin ( );
+  while ( it != pEntry->listFileInfos.end ( ) )  {
+    pInfo = *it++;
+    fileInfo.setFile ( pInfo->qsFileName );
+    if ( pInfo->listChapters.count  ( ) == 0 )  // make sure at least one chapter is present ...
+         pInfo->listChapters.append ( "00:00:00.000" );
+    for ( t=0; t<(int)pInfo->listChapters.count ( ); t++ )  {
+      qsChapter = pInfo->listChapters[t] + " : " + fileInfo.fileName ( );
+      listChapters.append ( qsChapter );
+    }
+  }
+
+  m_pListBoxChapters->insertStringList ( listChapters );
+  m_pProgressBar->setTotalSteps ( pInfo->listChapters.count( ) - 1 );
+
+  refreshEntry ( true );
+}
+
 void DialogThumbnail::initSourceFileInfo ( SourceFileInfo *pInfo, QString &qsAction )
 {
   m_pListBoxChapters   ->clear ( );
   m_pIconViewThumbnails->clear ( );
 
   if ( ! pInfo )
-    return;  
+    return;
 
-  QFileInfo fileInfo ( pInfo->qsFileName );
+  QFileInfo   fileInfo ( pInfo->qsFileName );
   setCaption ( QString ( "Thumbnail Dialog : " ) + fileInfo.fileName ( ) );
-  m_pSourceFileInfo = pInfo;
-  m_qsActionString  = qsAction;
+  m_pSourceFileInfo  = pInfo;
+  m_pSourceFileEntry = NULL;
+  m_qsActionString   = qsAction;
   m_pListBoxChapters->insertStringList ( pInfo->listChapters );
   m_pProgressBar->setTotalSteps ( pInfo->listChapters.count( ) - 1 );
 
@@ -148,32 +296,34 @@ void DialogThumbnail::initSourceFileInfo ( SourceFileInfo *pInfo, QString &qsAct
 
 void DialogThumbnail::timerEvent ( QTimerEvent *pEvent )
 {
-  if ( m_pSourceFileInfo && pEvent->timerId ( ) == MEDIASCANNER_EVENT + 4 ) {
-    int t;
-    WorkWaiting *pWork;
-    QValueList<WorkWaiting *> tempList;
-    // to decrease threading issues, we quickly remove the used Work objects from the member list.
-    for ( t=0;t<(int)m_listOfWorkToDo.count ( ); t++ ) {
-      pWork = m_listOfWorkToDo [ t ];
-      m_listOfWorkToDo.remove ( pWork );
-      tempList.append ( pWork );
+  if ( haveSource ( ) )  {
+    if ( pEvent->timerId ( ) == MEDIASCANNER_EVENT + 4 ) {
+      int t;
+      WorkWaiting *pWork;
+      QValueList<WorkWaiting *> tempList;
+      // to decrease threading issues, we quickly remove the used Work objects from the member list.
+      for ( t=0;t<(int)m_listOfWorkToDo.count ( ); t++ ) {
+        pWork = m_listOfWorkToDo [ t ];
+        //m_listOfWorkToDo.remove ( pWork );
+        tempList.append ( pWork );
+      }
+      m_listOfWorkToDo.clear ( );
+      for ( t=0;t<(int)tempList.count ( ); t++ ) {
+        pWork = tempList [ t ];
+        updateItem ( pWork->pItem, pWork->pImage, pWork->qsFileName );
+        delete pWork;
+        m_pProgressBar->setProgress ( m_iProgress ++ );
+      }
+      if ( (int)m_iProgress >= m_pProgressBar->totalSteps ( )-2 )
+        m_pIconViewThumbnails->arrangeItemsInGrid ( TRUE );
     }
-    for ( t=0;t<(int)tempList.count ( ); t++ ) {
-      pWork = tempList [ t ];
-      updateItem ( pWork->pItem, pWork->pImage );
-      delete pWork;
-      m_pProgressBar->setProgress ( m_iProgress ++ );
-    }
-    if ( (int)m_iProgress >= m_pProgressBar->totalSteps ( )-2 )
-      m_pIconViewThumbnails->arrangeItemsInGrid ( TRUE );
   }
-
   uiDialogThumbnail::timerEvent ( pEvent );
 }
 
-void DialogThumbnail::initWork ( QIconViewItem *pItem, QImage *pImage )
+void DialogThumbnail::initWork ( QIconViewItem *pItem, QImage *pImage, QString qsFile )
 {
-  WorkWaiting *pNewWork = new WorkWaiting ( pItem, pImage );
+  WorkWaiting *pNewWork = new WorkWaiting ( pItem, pImage, qsFile );
   m_listOfWorkToDo.append ( pNewWork );
 }
 
@@ -191,26 +341,30 @@ QString DialogThumbnail::getChapter ( QIconViewItem *pItem )
 {
   QString qsChapter;
   if ( pItem )  {
-  	QStringList list = QStringList::split ( STRING_SEPARATOR, pItem->key ( ) );
-  	qsChapter = list[ list.size ( ) - 1 ];
+    QStringList list = QStringList::split ( STRING_SEPARATOR, pItem->key ( ) );
+    if ( list.count ( ) > 0 )
+      qsChapter = list[ list.size ( ) - 1 ];
+    else
+      qsChapter = "00:00:00.000";
   }
   return  qsChapter;
 }
 
-bool DialogThumbnail::updateItem ( QIconViewItem *pItem, QImage *pImage )
+bool DialogThumbnail::updateItem ( QIconViewItem *pItem, QImage *pImage, QString qsFile )
 {
   if ( ! pImage )
     return false;
 
   QString   qsFileName, qsChapter;
   Utils     theUtils;
-  QFileInfo fileInfo ( m_pSourceFileInfo->qsFileName );
-    
+//  QFileInfo fileInfo ( m_pSourceFileInfo->qsFileName );
+  QFileInfo fileInfo ( qsFile );
+
   // At this point we should add the image to the IconView ...
-  qsChapter  = getChapter ( pItem );
+  qsChapter  = getChapter         ( pItem );
   qsChapter  =  qsChapter.remove  ( ':' );
   qsChapter  =  qsChapter.replace ( '.', "_" );
-  
+
   qsFileName  = theUtils.getTempPath ( fileInfo.baseName ( ) );
   qsFileName += QString ( "/thumb_%1.png" ).arg  ( qsChapter );
   pImage->save ( qsFileName, "PNG", 100 );
@@ -236,7 +390,7 @@ bool DialogThumbnail::getBufferedThumbnail ( )
 {
   QIconViewItem *pItem = NULL;
 
-  while ( m_iCurrentChapter < m_pSourceFileInfo->listChapters.count ( ) ) {
+  while ( (int)m_iCurrentChapter < chapterCount ( ) ) {
     pItem = createCurrentItem ( false );
     if ( ! pItem )
       return true;
@@ -250,9 +404,9 @@ bool DialogThumbnail::getBufferedThumbnail ( )
 void DialogThumbnail::slotFrame ( )
 {
   DialogFrame frameDialog ( this );
-  frameDialog.initMe      ( m_frameAttr.iStyle, 
-			    m_frameAttr.iWidth, 
-			    m_frameAttr.iJoin, 
+  frameDialog.initMe      ( m_frameAttr.iStyle,
+			    m_frameAttr.iWidth,
+			    m_frameAttr.iJoin,
 			    m_frameAttr.color );
   if (  frameDialog.exec  (  ) == QDialog::Rejected )
     return;
@@ -313,13 +467,19 @@ void DialogThumbnail::setItemText ( QIconViewItem *pItem, int iTextType )
     qsText = qsChapter.left ( qsChapter.length ( ) - 4 );
   break;
   case 2: {
-    int t;
-    for ( t=0;t<(int)m_pSourceFileInfo->listChapters.count ( ); t++ ) {
-      if ( m_pSourceFileInfo->listChapters[ t ] == qsChapter ) {
-	qsText = QString (  "Chapter %1" ).arg ( t + 1 );
-	break;
+    if ( m_pSourceFileInfo )  {
+      int t, iChapterCount = chapterCount ( );
+      for  ( t=0;t<iChapterCount; t++ ) {
+        if ( chapter  ( t ) == qsChapter ) {
+          qsText = QString (  "Chapter %1" ).arg ( t + 1 );
+          break;
+        }
       }
     }
+    if ( m_pSourceFileEntry )  {
+      int  t = getChapterNumberFromKey ( pItem->key ( ) );
+      qsText = QString (  "Chapter %1" ).arg  ( t + 1 );
+    }
   }
   break;
   };
@@ -376,8 +536,11 @@ void DialogThumbnail::slotChapterChanged ( QListBoxItem *pListBoxItem )
   if ( ! pListBoxItem )
     return;
 
+  if ( m_pSourceFileEntry )
+    chapterChanged ( pListBoxItem );
+
   int t;
-  QString qsChapter = pListBoxItem->text ( );
+  QString qsChapter    = pListBoxItem->text ( );
   QIconViewItem *pItem = m_pIconViewThumbnails->firstItem ( );
   // First we ensure the current item is visible
   while ( pItem ) {
@@ -393,6 +556,7 @@ void DialogThumbnail::slotChapterChanged ( QListBoxItem *pListBoxItem )
   // chapter that has been selected (multiple selection)
   for ( t=0;t<(int)m_pListBoxChapters->count ( ); t++ ) {
     pListBoxItem = m_pListBoxChapters->item ( t );
+    qsChapter    = pListBoxItem->text ( );
     if ( pListBoxItem && pListBoxItem->isSelected ( ) ) {
 //printf ( "DialogThumbnail::chapterChanged <%p>\n", pListBoxItem );
       // Okay, and for this selected ListBox item, we find the 
@@ -400,37 +564,74 @@ void DialogThumbnail::slotChapterChanged ( QListBoxItem *pListBoxItem )
       pItem = m_pIconViewThumbnails->firstItem ( );
       // First we ensure the current item is visible
       while ( pItem ) {
-	if  ( getChapter ( pItem ) == qsChapter ) {
-	  m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE );
-	  pItem = NULL;
-	}
-	else
-	  pItem = pItem->nextItem ( );
+        if  ( getChapter ( pItem ) == qsChapter ) {
+          m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE );
+          pItem = NULL;
+        }
+        else
+          pItem = pItem->nextItem ( );
       }
     }
   }
 }
-/*
-void DialogThumbnail::slotChapterChanged ( QListBoxItem *pListBoxItem )
+
+void DialogThumbnail::chapterChanged ( QListBoxItem *pListBoxItem )
 {
-// This one is for single selection only ...
-  printf ( "DialogThumbnail::chapterChanged <%p>\n", pListBoxItem );
+  // Called when te user selects items in the ListBox on the left hand side.
   if ( ! pListBoxItem )
     return;
+  // This function handles SourceFileEntries
+  // key = 00:00:00.000 : FileName.mpg
 
-  QString qsChapter = pListBoxItem->text ( );
-  QIconViewItem *pItem = m_pIconViewThumbnails->firstItem ( );
-  
-  while ( pItem ) {
-    if  ( getChapter ( pItem ) == qsChapter ) {
-      m_pIconViewThumbnails->clearSelection    ( );
-      m_pIconViewThumbnails->ensureItemVisible ( pItem );
-      pItem->setSelected    ( true );
+  QStringList list = QStringList::split ( " : ", pListBoxItem->text ( ) );
+  if ( list.count ( ) == 2 )  {
+    QString qsChapter, qsFileName, qsSearchKey;
+    qsChapter   = list[0];
+    qsFileName  = list[1];
+    qsSearchKey = QString ( "jump+-+%1+-+%2+-+%3" ).arg ( m_pSourceFileEntry->qsDisplayName ).arg ( qsFileName ).arg ( qsChapter );
+
+    QIconViewItem *pItem = m_pIconViewThumbnails->firstItem ( );
+    // First we ensure the current item is visible
+    while ( pItem ) {
+      if  ( pItem->key ( ) == qsSearchKey )  {
+        m_pIconViewThumbnails->clearSelection    ( );
+        m_pIconViewThumbnails->ensureItemVisible ( pItem );
+        //m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE );
+        break;
+      }
+      pItem = pItem->nextItem ( );
+    }
+  }
+
+  // Next we loop through the ListBox and find each 
+  // chapter that has been selected (multiple selection)
+  QIconViewItem *pItem = NULL;
+  for ( int t=0;t<(int)m_pListBoxChapters->count ( ); t++ ) {
+    pListBoxItem = m_pListBoxChapters->item ( t );
+    if ( pListBoxItem && pListBoxItem->isSelected ( ) ) {
+      QStringList list = QStringList::split ( " : ", pListBoxItem->text ( ) );
+      if ( list.count ( ) == 2 )  {
+        QString qsChapter, qsFileName, qsSearchKey;
+        qsChapter   = list[0];
+        qsFileName  = list[1];
+        qsSearchKey = QString ( "jump+-+%1+-+%2+-+%3" ).arg ( m_pSourceFileEntry->qsDisplayName ).arg ( qsFileName ).arg ( qsChapter );
+
+        // Okay, and for this selected ListBox item, we find the 
+        // associciated IconViewItem and do also sect it.
+        pItem = m_pIconViewThumbnails->firstItem ( );
+        // First we ensure the current item is visible
+        while ( pItem ) {
+          if  ( pItem->key ( ) == qsSearchKey  ) {
+            m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE );
+            pItem = NULL;
+          }
+          else
+            pItem = pItem->nextItem ( );
+        }
+      }
     }
-    pItem = pItem->nextItem ( );
   }
 }
-*/
 
 void DialogThumbnail::slotReload ( )
 {
@@ -446,16 +647,16 @@ void DialogThumbnail::slotRefresh ( )
 void DialogThumbnail::refresh ( bool bForceReload )
 {
   bool bOkay;
+  int  iChapterCount = chapterCount ( );
 
   m_pProgressBar->reset ( );
   m_pIconViewThumbnails->clear ( );
   m_iCurrentChapter = 0;
-  m_iProgress       = 0;
+  m_iProgress       = iChapterCount;
 
-  if ( ( ! m_pSourceFileInfo ) || ( m_pSourceFileInfo->listChapters.count ( ) < 1 ) )
+  if ( iChapterCount < 1 )
     return;
 
-  m_iProgress = m_pSourceFileInfo->listChapters.count ( );
   // First we should remove outstanding tasks ...
   MediaCreator::unregisterFromMediaScanner ( this );
 
@@ -469,16 +670,18 @@ void DialogThumbnail::refresh ( bool bForceReload )
 
   m_iThumbnailStretchMode = m_pComboStretch->currentItem ( );
 
-  while ( m_iCurrentChapter < m_pSourceFileInfo->listChapters.count ( ) ) {
+  while ( (int)m_iCurrentChapter < iChapterCount ) {
     if  ( bForceReload || getBufferedThumbnail ( ) ) {
       ThumbnailRequest *pRequest = NULL;
-      //pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
+      SourceFileInfo   *pInfo    = getInfoFromChapterNumber ( m_iCurrentChapter );
+      if ( ! pInfo )
+        continue;
 
-      Utils theUtils;  
-      long  iMSecOffset = theUtils.getMsFromString ( m_pSourceFileInfo->listChapters[ m_iCurrentChapter ] );
+      Utils theUtils;
+      long  iMSecOffset    = theUtils.getMsFromString ( chapter ( m_iCurrentChapter ) );
       QIconViewItem *pItem = createCurrentItem ( true );
 
-      pRequest = new ThumbnailRequest ( this, pItem, m_pSourceFileInfo->qsFileName, iMSecOffset );
+      pRequest = new ThumbnailRequest ( this, pItem, pInfo->qsFileName, iMSecOffset );
       MediaCreator::registerWithMediaScanner ( pRequest );
       m_iProgress --;       // for every requeste thumbnail we decrease the progress.
       m_iCurrentChapter ++; // Also every requested thumbnail should increase the currentCHapter counter.
@@ -489,45 +692,115 @@ void DialogThumbnail::refresh ( bool bForceReload )
   slotTextType ( iTextType );
 }
 
+void DialogThumbnail::refreshEntry ( bool bForceReload )
+{
+  // Only called from initSourceFileEntry ( )
+  bool  bOkay;
+  Utils theUtils;
+  int   t, iChapterCount;
+
+  m_pProgressBar->reset ( );
+  m_pIconViewThumbnails->clear ( );
+  m_iCurrentChapter = 0;
+  m_iProgress       = 0;
+
+  if ( ! m_pSourceFileEntry )
+    return;
+
+  iChapterCount = chapterCount ( );
+  m_iProgress   = iChapterCount;
+
+  // First we should remove outstanding tasks ...
+  MediaCreator::unregisterFromMediaScanner ( this );
+
+  m_iThumbnailWidth = m_pEditWidth->text ( ).toInt ( &bOkay );
+  if ( ! bOkay )
+    m_iThumbnailWidth = 120;
+
+  m_iThumbnailHeight = m_pEditHeight->text ( ).toInt ( &bOkay );
+  if ( ! bOkay )
+    m_iThumbnailHeight = 120;
+
+  m_iThumbnailStretchMode = m_pComboStretch->currentItem ( );
+
+  QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+  SourceFileInfo *pInfo;
+  while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {  //m_iCurrentChapter < iChapterCount ) {
+    pInfo = *it++;
+    if ( ! pInfo )
+      continue;
+
+    for ( t=0; t<(int)pInfo->listChapters.count ( ); t++ )  {
+      if  ( bForceReload )  { //|| getBufferedThumbnail ( ) ) {
+        ThumbnailRequest *pRequest = NULL;
+        //pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
+
+        long iMSecOffset = theUtils.getMsFromString (               pInfo->listChapters [ t ] );
+        QIconViewItem *pItem = createCurrentItem    (  pInfo, true, pInfo->listChapters [ t ] );
+        pRequest = new ThumbnailRequest ( this, pItem, pInfo->qsFileName, iMSecOffset );
+        MediaCreator::registerWithMediaScanner ( pRequest );
+        m_iProgress --;       // for every requeste thumbnail we decrease the progress.
+        m_iCurrentChapter ++; // Also every requested thumbnail should increase the currentCHapter counter.
+      }
+    }
+  }
+  m_pProgressBar->setProgress ( m_iProgress );
+  int iTextType = m_pComboTextType->currentItem ( );
+  slotTextType ( iTextType );
+}
+
 QIconViewItem *DialogThumbnail::createCurrentItem ( bool bPleaseWait )
 {
-  QIconViewItem *pItem = NULL;
-  QString qsChapter;
+  SourceFileInfo *pInfo = getInfoFromChapterNumber ( m_iCurrentChapter );
+  return createCurrentItem ( pInfo, bPleaseWait, chapter ( m_iCurrentChapter ) );
+}
+
+QIconViewItem *DialogThumbnail::createCurrentItem ( SourceFileInfo *pInfo, bool bPleaseWait, QString qsChapter )
+{
+  QIconViewItem *pItem   = NULL;
   QImage  theImage;
+  QString qsActionString = m_qsActionString;
 
   QImage::ScaleMode scaleMode = QImage::ScaleMin;
   if ( m_iThumbnailStretchMode ==  1 )
     scaleMode = QImage::ScaleMax;
   if ( m_iThumbnailStretchMode ==  2 )
     scaleMode = QImage::ScaleFree;
-  
+
   if ( bPleaseWait )
     theImage = QImage ( QImage ( ).fromMimeSource ( "please_wait.jpg" ) );
-  else {
+  else if ( pInfo )  {
     Utils     theUtils;
-    QString   qsFileName, qsBaseName;
-    QFileInfo fileInfo ( m_pSourceFileInfo->qsFileName );
-    qsBaseName = theUtils.getTempPath ( fileInfo.baseName ( ) );
-    qsChapter  = m_pSourceFileInfo->listChapters [ m_iCurrentChapter ];
-    qsChapter  = qsChapter.remove  ( ':' );
-    qsChapter  = qsChapter.replace ( '.', "_" );
-    qsFileName = qsBaseName + QString ( "/thumb_%1.png" ).arg ( qsChapter );
+    QString   qsFileName, qsBaseName, qsFNChapter;
+    QFileInfo fileInfo ( pInfo->qsFileName );
+    qsBaseName  = theUtils.getTempPath ( fileInfo.baseName ( ) );
+    qsFNChapter = qsChapter;
+    qsFNChapter = qsFNChapter.remove   ( ':' );
+    qsFNChapter = qsFNChapter.replace  ( '.', "_" );
+    qsFileName  = qsBaseName + QString ( "/thumb_%1.png" ).arg ( qsFNChapter );
     if ( ! theImage.load ( qsFileName ) )
       return NULL;
 
     if ( theImage.isNull ( ) )
       return NULL;
   }
-  theImage = theImage.smoothScale ( m_iThumbnailWidth, m_iThumbnailHeight, scaleMode );
 
-  qsChapter  = m_pSourceFileInfo->listChapters [ m_iCurrentChapter ];
-  pItem = new QIconViewItem ( m_pIconViewThumbnails, qsChapter );
+  if ( pInfo && m_pSourceFileEntry )  {
+    // The m_qsActionString for the m_pSourceFileEntry is always ""
+    // So we'll have to build out command here ...
+    QFileInfo fileInfo       ( pInfo->qsFileName );
+    qsActionString = QString ( "jump+-+%1+-+%2+-+" ).arg ( m_pSourceFileEntry->qsDisplayName ).arg ( fileInfo.fileName ( ) );
+  }
+
+  theImage  = theImage.smoothScale ( m_iThumbnailWidth, m_iThumbnailHeight, scaleMode );
+  pItem     = new QIconViewItem    ( m_pIconViewThumbnails, qsChapter );
   if ( pItem ) {
     QPixmap thePixmap;
     if ( thePixmap.convertFromImage ( theImage ) ) {
       pItem->setPixmap ( thePixmap );
-      pItem->setKey    ( m_qsActionString + qsChapter );
+      pItem->setKey    ( qsActionString + qsChapter );
     }
   }
   return pItem;
 }
+
