@@ -194,28 +194,28 @@ bool DVDAuthor::populateListOfTitlesets ()
       qsFormat = createFormatString ( pInfo, true );
 
       if ( pInfo->iTitleset > 0 ) {  // user set titleset number.
-	pTitleset = addToTitleset ( pEntry, pInfo->iTitleset, true );
-	bFound = true;
+        pTitleset = addToTitleset ( pEntry, pInfo->iTitleset, true );
+        bFound = true;
       }
       else {	// Next we check if we can find a titleset with the same format.
-	for ( i=0;i<m_listTitlesets.count();i++)  {
-	  pTitleset = m_listTitlesets[i];
+        for ( i=0;i<m_listTitlesets.count();i++)  {
+          pTitleset = m_listTitlesets[i];
           // Note: If the user assigns Titleset numbers then we should not add any additional videos to this titleset
-	  if ( ( pTitleset->qsFormat == qsFormat ) && ( ! pTitleset->bSetByUser ) ) {
-	    pTitleset = addToTitleset ( pEntry, pTitleset->iTitlesetNumber );
-	    bFound = true;
-	    break; // exit the loop
-	  }
-	}
+          if ( ( pTitleset->qsFormat == qsFormat ) && ( ! pTitleset->bSetByUser ) ) {
+            pTitleset = addToTitleset ( pEntry, pTitleset->iTitlesetNumber );
+            bFound = true;
+            break; // exit the loop
+          }
+        }
       }
       // check if we could handle this movie yet.
       if ( ! bFound )  {
-	iTitleset = getFirstEmptyTitleset ( );
-	pTitleset = addToTitleset ( pEntry, iTitleset );
+        iTitleset = getFirstEmptyTitleset ( );
+        pTitleset = addToTitleset ( pEntry, iTitleset );
       }
       if ( ! pTitleset ) {
-	fprintf ( stderr, "Error, Could not add titleset for menu <%s> with format:<%s>\n", pMenu->name ( ).ascii ( ), qsFormat.ascii ( ) );
-	return false; //ERROR ..
+        fprintf ( stderr, "Error, Could not add titleset for menu <%s> with format:<%s>\n", pMenu->name ( ).ascii ( ), qsFormat.ascii ( ) );
+        return false; //ERROR ..
       }
     }
 
@@ -406,7 +406,7 @@ bool DVDAuthor::createJumpTable ( )
 	  pJumpTableEntry->iMenu      = pTitleset->findMenu ( pButtonMenu );
 	  pJumpTableEntry->pMenu      = pButtonMenu;
 	  optimizeJumpTable ( pTitleset, pJumpTableEntry );
-	  
+
 	  if ( pMenuTitleset == pTitleset ) {
 	    if ( pJumpTableEntry->iMenu == 0 )
 	      qsAction += QString ("g3=0; call menu entry root; } ");
@@ -515,13 +515,13 @@ void DVDAuthor::createPlayMultiple ( ButtonObject *pButton, DVDMenu *pDVDMenu, u
 
     if ( ( ! pTargetInfo ) || ( ! pSourceInfo ) )
       continue;
-    
+
     pMultiple = findMultiple ( pSourceInfo, false );
     if ( ! pMultiple ) {
       pMultiple = new PlayMultiple ( pSourceInfo, pTargetInfo );
       m_listPlayMultiple.append    ( pMultiple );
     }
-    
+
     pTargetTitleset = findTitleset ( pTargetInfo );
     if ( ( ! pTargetTitleset )  || ( ! pSourceTitleset ) ) 
       continue;
@@ -534,7 +534,7 @@ void DVDAuthor::createPlayMultiple ( ButtonObject *pButton, DVDMenu *pDVDMenu, u
                                   pTargetTitleset->getTotalChapters ( pTargetInfo );
     pJumpTableEntry->pButton    = pButton;
     optimizeJumpTable ( pTargetTitleset, pJumpTableEntry );
-    
+
     qsPlayMultiple = QString ( "\t\tif ( g5 eq %1 ) { " ).arg ( iPlayMultipleIdx );
     // Add button and buttonAction ...
     if ( pSourceTitleset == pTargetTitleset ) {
@@ -554,11 +554,11 @@ void DVDAuthor::createPlayMultiple ( ButtonObject *pButton, DVDMenu *pDVDMenu, u
 	 ( ! pButton->getLoopMultiple ( )  )  )    // ... but only if the user does NOT want to loop
       qsPlayMultiple += "g5 = 0; ";
     qsPlayMultiple += "}";
-    
+
     pMultiple->addPlayMultiple ( qsPlayMultiple );
     if ( pJumpTableEntry )
          pTargetTitleset->listJumpTable.append ( pJumpTableEntry );
-    
+
     // lastly we set the new sourceTitleset and sourceInfo for the newxt loop
     pSourceTitleset = pTargetTitleset;
     pSourceInfo     = pTargetInfo;
@@ -631,7 +631,7 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
   CXmlDVDAuthor::titleset_struct *pXMLTitleset;
   CXmlDVDAuthor::menus_struct    *pXMLMenu;
   CXmlDVDAuthor::pgc_struct      *pPgc;
- 
+
   // main DVDAuthorXML - object
   CXmlDVDAuthor::titles_struct *pTitle;
   CXmlDVDAuthor         xmlDvdauthor;
@@ -682,10 +682,12 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
   qsPre   += QString ("\t\t}\n\t} ");
   pPgc->pre.value     = qsPre;
   pPgc->post.value    = QString (" { g4=button; g2=0; " );
-  if ( ! pInterface->qsPost.isEmpty ( ) )
-    pPgc->post.value += pInterface->qsPost;
-  else
+  if ( pInterface->qsPost.isEmpty ( ) )
     pPgc->post.value += QString ( "jump vmgm menu 1;" );
+  else if ( pInterface->qsPost = "Loop" ) // This is for the VMGMenu only ...
+    pPgc->post.value += QString ( "jump vmgm menu 1;" );
+  else
+    pPgc->post.value += pInterface->qsPost;
   pPgc->post.value   += QString ( " } ");
 
   CXmlDVDAuthor::vob_struct *pVob = NULL;
@@ -712,16 +714,16 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
     pXMLTitleset = xmlDvdauthor.m_dvdauthor.addTitleset();
     // check if we found an empty titleset.
     if ( pExpTitleset ) {
-
+      pXMLTitleset->comment = QString ( "Titleset %1" ).arg ( pExpTitleset->iTitlesetNumber );
       addToMenu ( pXMLTitleset, pExpTitleset );
 
       // Next we insert all Menus ...
       for ( i=0; i<pExpTitleset->listMenus.count ( ); i++ )
-	addToMenu( pXMLTitleset, pExpTitleset->listMenus[i] );
+        addToMenu ( pXMLTitleset, pExpTitleset->listMenus[i] );
 
       // Next we insert all SourceFileInfos ...
       for ( i=0; i<pExpTitleset->listSourceFileEntries.count ( ); i++ )
-	addToTitleset ( pXMLTitleset, pExpTitleset->listSourceFileEntries[i] );
+        addToTitleset ( pXMLTitleset, pExpTitleset->listSourceFileEntries[i] );
     }
 
     // Each Titleset ought to have at least one title with one pgc
@@ -731,7 +733,7 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
     }
 
     // Found out the hard way that a Titleset also ought to possess at least one menu - pgc - entry.
-    if ( ! pXMLTitleset->ppArrayMenus )  {
+    if ( ! pXMLTitleset->ppArrayMenus )   {
       pXMLMenu = pXMLTitleset->addMenus ( );
       pXMLMenu->addPgc ( );
     }
@@ -742,7 +744,7 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
   return true;
 }
 
-ExportTitleset *DVDAuthor::addToTitleset (SourceFileEntry *pEntry, int iTitleset, bool bSetByUser /* = false */ )
+ExportTitleset *DVDAuthor::addToTitleset ( SourceFileEntry *pEntry, int iTitleset, bool bSetByUser /* = false */ )
 {
   uint t, i;
   bool bFound = false;
@@ -767,36 +769,36 @@ ExportTitleset *DVDAuthor::addToTitleset (SourceFileEntry *pEntry, int iTitleset
       }
       // check if we already assigned this TitlesetNumber to some other video format that does not match
       if ( ( qsFormat != pTitleset->qsFormat ) )  {
-	iTitleset = getFirstEmptyTitleset  ( );
-	// exit out of for-loop to create a new Titleset
-	t=m_listTitlesets.count() + 1;
-	bFound = false;
-	continue;
+        iTitleset = getFirstEmptyTitleset  ( );
+        // exit out of for-loop to create a new Titleset
+        t=m_listTitlesets.count() + 1;
+        bFound = false;
+        continue;
       }
-      
+
       // Next run through the SourceFileInfo list and make sure the SourceFileInfo is not already present.
-      for (i=0;i<pTitleset->listSourceFileEntries.count();i++)  {
-	pTSEntry = pTitleset->listSourceFileEntries[i];
-	//if ( pTitleset->listSourceFileEntries[i] == pEntry ) { // would generate muliple PGS for the same Entry if it comes from different menus.
-	if ( pTSEntry->qsDisplayName == pEntry->qsDisplayName ) {
-	  bFound = true;
-	  break;
-	}
+      for ( i=0; i<pTitleset->listSourceFileEntries.count ( ); i++ )  {
+        pTSEntry = pTitleset->listSourceFileEntries[i];
+        //if ( pTitleset->listSourceFileEntries[i] == pEntry ) { // would generate muliple PGS for the same Entry if it comes from different menus.
+        if ( pTSEntry->qsDisplayName == pEntry->qsDisplayName ) {
+          bFound = true;
+          break;
+        }
       }
       if ( ! bFound )  {
-	pTitleset->listSourceFileEntries.append ( pEntry );
-	if ( ! pTitleset->bSetByUser ) 
-	  pTitleset->bSetByUser = bSetByUser;
+        pTitleset->listSourceFileEntries.append ( pEntry );
+        if ( ! pTitleset->bSetByUser ) 
+               pTitleset->bSetByUser = bSetByUser;
       }
       bFound = true;
     }
-    else  {
+    else {
       // Next we check if this entry is in any other titleset and remove it
-      for (i=0;i<pTitleset->listSourceFileEntries.count();i++)  {
-	pTSEntry = pTitleset->listSourceFileEntries[i];
-	//if ( pTitleset->listSourceFileEntries[i] == pEntry ) // see above
-	if ( pTSEntry->qsDisplayName == pEntry->qsDisplayName )
-	  pTitleset->listSourceFileEntries.remove ( pEntry );
+      for ( i=0; i<pTitleset->listSourceFileEntries.count ( ); i++ )  {
+        pTSEntry = pTitleset->listSourceFileEntries[i];
+        //if ( pTitleset->listSourceFileEntries[i] == pEntry ) // see above
+        if ( pTSEntry->qsDisplayName == pEntry->qsDisplayName )
+            pTitleset->listSourceFileEntries.remove  ( pEntry );
       }
     }
   }
@@ -809,7 +811,7 @@ ExportTitleset *DVDAuthor::addToTitleset (SourceFileEntry *pEntry, int iTitleset
     pTitleset->bSetByUser      = bSetByUser;
     m_listTitlesets.append ( pTitleset );
   }
-  
+
   // NOTE: This algo can result in empty titlesets (no associated SourceFileInfos ) if the user defines the titlesetNumber
   //       fo a given SourceFileInfo / SourceFileEntry.	
   return pTitleset;
@@ -826,29 +828,29 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titleset_struct *pXMLTitleset, So
   // iLOG ("pEntry=<%p> count=%d", pEntry,  pEntry->listFileInfos.count() );
   if ( ! pXMLTitleset->ppArrayTitles ) {
     pTitle = pXMLTitleset->addTitles ( );
-    
+
     iMaxAudio = pEntry->audioCount ( true );
     for ( t=0;t<=iMaxAudio; t++ ) {
       if ( pEntry->arrayAudioEntries[ t ].iAudioNumber == -1 )
-	pTitle->audio [ t ].lang = "en"; // default to english if nothing has been specified.
+        pTitle->audio [ t ].lang = "en"; // default to english if nothing has been specified.
       //pTitle->audio [ pEntry->arrayAudioEntries[ t ].iAudioNumber ]. lang = pEntry->arrayAudioEntries[ t ].qsIso639;
       pTitle->audio [ t ].lang = pEntry->arrayAudioEntries[ t ].qsIso639;
     }
     iMaxSubtitle = pEntry->subtitleCount ( true );
     for ( t=0;t<iMaxSubtitle+1; t++ ) {
       if ( pEntry->arraySubtitleEntries[ t ].m_iSubtitleNumber == -1 )
-	pTitle->subpicture [ t ].lang = "en"; // default to english if nothing has been specified.
+        pTitle->subpicture [ t ].lang = "en"; // default to english if nothing has been specified.
       pTitle->subpicture [ t ].lang = pEntry->arraySubtitleEntries[ t ].m_qsIso639;
     }
 
     if ( pEntry->listFileInfos.count() ) {
       pInfo = pEntry->listFileInfos[0];
-      if ( pInfo ) {
-	p = pInfo->pTranscodeInterface;
-	if ( p )
-	  addToVideo ( &pTitle->video, p->qsResolution, p->qsRatio );	  
-	else
-	  addToVideo ( &pTitle->video, pInfo->qsResolution, pInfo->qsRatio );
+      if ( pInfo )  {
+        p = pInfo->pTranscodeInterface;
+        if ( p )
+          addToVideo ( &pTitle->video, p->qsResolution, p->qsRatio );
+        else
+          addToVideo ( &pTitle->video, pInfo->qsResolution, pInfo->qsRatio );
       }
     }
   }
@@ -868,6 +870,8 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titles_struct *pTitle, SourceFile
 
   if ( ! temp.checkForPrePostCommands ( pEntry, true ) ) { // true == the fist pPgc can have a pre and the last is allowed to have a post command
     pPgc = pTitle->addPgc ( );
+    pPgc->comment = QString ( "Title %1" ).arg ( pTitle->pgcCount ( ) );
+
     return addToTitleset  ( pPgc, pEntry );
   }
 
@@ -878,6 +882,7 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titles_struct *pTitle, SourceFile
   for (i=0;i<pEntry->listFileInfos.count();i++) {
     pPgc = pTitle->addPgc ( );
     addToTitleset ( pPgc, pEntry->listFileInfos[i] );
+
     // just in case to ensure something is happening afterwards.
     if ( pPgc->post.value.isEmpty ( ) )
          pPgc->post.value = " { g2 = 0; call vmgm menu entry title; } ";
@@ -898,8 +903,6 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::pgc_struct *pPgc, SourceFileInfo
   if ( pMultiple )
     pPgc->post.value = pMultiple->getPostCommand ( );
 
-  //printf ( "Line 891 : fileName<%s> multi:Post <%s>\n", pInfo->qsFileName.ascii(), pMultiple ? pMultiple->getPostCommand ( ).ascii ( ) : "NULL" );
-
   pPgc->post.value  += pInfo->qsPostCommand;
 
   pVob = pPgc->addVob ( );
@@ -945,7 +948,7 @@ QString DVDAuthor::jumpToSubMenu ( SourceFileEntry *pEntry )
   pJumpTableEntry = pMenuTitleset->findJumpTable ( pDVDMenu );
   if ( ! pJumpTableEntry )
     return qsJump;
-    
+
   iMenu  = pMenuTitleset->findMenu ( pDVDMenu );
   if ( pMenuTitleset == pEntryTitleset ) {
     if ( pJumpTableEntry->iMenu == 0 )
@@ -963,16 +966,16 @@ QString DVDAuthor::jumpToSubMenu ( SourceFileEntry *pEntry )
 bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::pgc_struct *pPgc, SourceFileEntry *pEntry )
 {
   uint i;
-  for ( i=0; i<pEntry->listFileInfos.count ( ); i++ ) 
-    addToTitleset ( pPgc, pEntry->listFileInfos[i] );
-  
+  for ( i=0; i<pEntry->listFileInfos.count ( ); i++ )
+     addToTitleset ( pPgc, pEntry->listFileInfos[i] );
+
   pPgc->pre.value  = pEntry->qsPre  + pPgc->pre.value;
   pPgc->post.value = pEntry->qsPost + pPgc->post.value;
 
   if ( pEntry->qsPost.isEmpty ( ) )
     pPgc->post.value = jumpToSubMenu ( pEntry );
   //pPgc->post.value = QString (" { g2 = 0; call vmgm menu entry title; } ");
-    
+
   if ( pEntry->iPause == -1 )
     pPgc->pause = QString ("inf");
   else
@@ -996,7 +999,7 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::titleset_struct *pXMLTitleset, Export
     // Note there ought to be only one <menus> - tag.
     // my mistake for not understanding the dvdauthor-XML-spec
     if ( ! pXMLTitleset->ppArrayMenus )
-      pXMLTitleset->addMenus ();
+           pXMLTitleset->addMenus   ( );
     pXMLMenu = pXMLTitleset->ppArrayMenus[0];
 
     return addToMenu ( pXMLMenu, pExpTitleset );
@@ -1008,7 +1011,7 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::menus_struct *pXMLMenu, ExportTitlese
 {
   CXmlDVDAuthor::pgc_struct *pPgc;
 
-  pPgc = pXMLMenu->addPgc ();
+  pPgc = pXMLMenu->addPgc ( );
   return addToMenu ( pPgc, pExpTitleset );
 }
 
@@ -1016,7 +1019,7 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::pgc_struct *pPgc, ExportTitleset *pEx
 {
   uint i;
   QString qsPre;
- 
+
   pPgc->entry=QString ("root");
   qsPre = QString (" {   if ( g3 gt 0 )  {\n");
   for ( i=0;i<pExpTitleset->listJumpTable.count();i++) {
@@ -1027,19 +1030,19 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::pgc_struct *pPgc, ExportTitleset *pEx
       continue;
     if ( p->iMenu > -1 ) {
       // The following line confuses the xine virtual machine and rejected calling the menu.
-      //qsPre += QString ("\t\tif ( g3 eq %1 ) { g3=0; jump menu %2; }\n").arg(p->iJumpIndex).arg(p->iMenu);
+      // qsPre += QString ("\t\tif ( g3 eq %1 ) { g3=0; jump menu %2; }\n").arg(p->iJumpIndex).arg(p->iMenu);
       // Note : .arg(p->iMenu+ 1); +1 caused error : ERR:  Cannot jump to menu PGC #3, only 2 exist
       qsPre += QString ("\t\tif ( g3 eq %1 ) jump menu %2; \n").arg(p->iJumpIndex).arg(p->iMenu); 
     }
     else {
       qsPre += QString ("\t\tif ( g3 eq %1 ) { g3=0; jump title %2 ").arg(p->iJumpIndex).arg(p->iTitle);
       if ( p->iChapter < 1 )
-	qsPre += QString ("; }\n");
+        qsPre += QString ("; }\n");
       else
-	qsPre += QString (" chapter %1; }\n").arg (p->iChapter);
+        qsPre += QString (" chapter %1; }\n").arg (p->iChapter);
     }
   }
-  
+
   qsPre   += QString ("\t\tjump vmgm menu entry title;\n");
   if ( m_bInsertComments )
     qsPre += QString (" <!-- nothing there, just start the first title // -->\n");
@@ -1073,21 +1076,21 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::titleset_struct *pXMLTitleset, DVDMen
     return true;
 
   if ( ! pXMLTitleset->ppArrayMenus )
-    pXMLTitleset->addMenus();
+         pXMLTitleset->addMenus   ( );
   pXMLMenu = pXMLTitleset->ppArrayMenus[0];
   return addToMenu ( pXMLMenu, pMenu );
 }
 
 bool DVDAuthor::addToMenu ( CXmlDVDAuthor::menus_struct *pXMLMenu, DVDMenu *pMenu )
 {
-  CDVDMenuInterface *pInterface = pMenu->getInterface();
+  CDVDMenuInterface *pInterface = pMenu->getInterface ( );
   CXmlDVDAuthor::pgc_struct      *pPgc;
   addToVideo ( &pXMLMenu->video, pInterface->iWidth, pInterface->iHeight, pInterface->qsRatio );
   addToAudio ( pXMLMenu, pMenu );
 
   pPgc = getPgc ( pXMLMenu, pMenu );
 
-  if ( ! pInterface->qsPre.isEmpty ( ) && pPgc->pre.value.isEmpty ( ) )
+  if ( ! pInterface->qsPre.isEmpty  ( ) && pPgc->pre.value.isEmpty  ( ) )
     pPgc->pre.value = pInterface->qsPre;
   if ( ! pInterface->qsPost.isEmpty ( ) && pPgc->post.value.isEmpty ( ) )
     pPgc->post.value = pInterface->qsPost;
@@ -1099,6 +1102,7 @@ CXmlDVDAuthor::pgc_struct *DVDAuthor::getPgc ( CXmlDVDAuthor::menus_struct *pXML
 {
   CDVDMenuInterface *pInterface = pMenu->getInterface ( );
   CXmlDVDAuthor::pgc_struct      *pPgc = NULL;
+  int t = 0;
 
   // Here we ensure that at least one Pgc is there.
   if  (  ! pXMLMenu->ppArrayPgc )
@@ -1106,7 +1110,7 @@ CXmlDVDAuthor::pgc_struct *DVDAuthor::getPgc ( CXmlDVDAuthor::menus_struct *pXML
 
   if ( pInterface->iMenu > -1 ) {
     // At this point we need to add PGCs for each missing Menu Numer ( In case the user define Menu=98 )
-    for ( int t=0; t<=pInterface->iMenu; t++ ) {
+    for ( t=0; t<=pInterface->iMenu; t++ ) {
       if (  !  pXMLMenu->ppArrayPgc[t] )
 	pPgc = pXMLMenu->addPgc     (  );
       else
@@ -1118,17 +1122,26 @@ CXmlDVDAuthor::pgc_struct *DVDAuthor::getPgc ( CXmlDVDAuthor::menus_struct *pXML
     }
   }
   else { // iMenu has not been set by the user
-    int t=1; // Start at menu # 1 as menu # 0(root) is used as Jumping block
+    t = 1; // Start at menu # 1 as menu # 0(root) is used as Jumping block
     pPgc = pXMLMenu->ppArrayPgc[0];
     while ( pPgc ) {
       pPgc = pXMLMenu->ppArrayPgc[t++];
       if ( pPgc && ! pPgc->ppArrayVob )
-	break;
+        break;
     }
     if ( ! pPgc )
       pPgc = pXMLMenu->addPgc (  );
   }
 
+  if ( pInterface->qsPost == "Loop" )  {
+    pPgc->post.value = QString ( " { g4=button; jump menu %1; } " ).arg ( t );
+    // We want to keep track of the highlighted button, to avoid flicker
+    pPgc->pre.value = "{ if ( g4 gt 0 ) button=g4; ";
+    if ( ! pInterface->qsPre.isEmpty ( ) && pPgc->pre.value.isEmpty ( ) )
+      pPgc->pre.value += pInterface->qsPre;
+    pPgc->pre.value += "}";
+  }
+
   return pPgc;
 }
 
@@ -1166,13 +1179,13 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::pgc_struct *pPgc, DVDMenu *pMenu )
   }
 
   if ( pInterface->qsPause.isEmpty ( ) )  {
-    if (pMenu->isMovieMenu ())
+    if ( pMenu->isMovieMenu ( ) )
       pVob->pause = QString ("0");
     else
       pVob->pause = QString ("inf");
   }
   else
-    pVob->pause = QString (  "%1" ).arg ( pInterface ->qsPause );
+    pVob->pause = pInterface ->qsPause;
 
   for ( t=0;t<listButtonsFromMenu.count();t++) {
     pButton = listButtonsFromMenu [ t ];
@@ -1393,7 +1406,7 @@ int DVDAuthor::getFirstEmptyTitleset ()
   }
   return iTitlesetNumber;
 }
- 
+
 void DVDAuthor::getButtonNumberFromName ( QValueList <ButtonObject *> &listButtons, QString &qsAction )
 {
   uint i;
@@ -1537,7 +1550,7 @@ bool DVDAuthor::cleanUpSourceFileEntries ( QValueList<SourceFileEntry *> &listEn
     for (i=1;i<pEntry->listFileInfos.count();i++) {
       pInfo1 = pEntry->listFileInfos[i];
       if ( ! pInfo1 )
-	continue;
+        continue;
 
       qsFormat2 = createFormatString ( pInfo1 );
       bFound = false;
@@ -1553,7 +1566,10 @@ bool DVDAuthor::cleanUpSourceFileEntries ( QValueList<SourceFileEntry *> &listEn
 	  qsFormat2 = createFormatString ( pInfo2 );
 	  if ( qsFormat1 == qsFormat2 ) {
 	    pEntry->listFileInfos.remove ( pInfo1 );
-	    m_listNewEntries[j]->listFileInfos.append ( pInfo1 );	    
+            // Make sure we only add the info one time to the Entry
+            // This could happen if we link from multiple DVDMenus to one video.
+            if ( m_listNewEntries[j]->listFileInfos.contains ( pInfo1 ) < 1 )
+	         m_listNewEntries[j]->listFileInfos.append   ( pInfo1 );
 	    bFound = true;
 	    break; // exit out of the inner loop listNewEntries.
 	  }
