@@ -90,6 +90,9 @@ void FrameObject::drawContents (QPainter *painter)
 {
         if ( m_pShadow && ! m_bDrawRect )
 	     m_pShadow->drawContents ( painter );
+	if ( m_colorFrame.alpha ( ) == 0 )
+	  return;
+
 	QWMatrix theMatrix;
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
