@@ -1,13 +1,17 @@
 /****************************************************************************
 ** Class Global implementation ...
 **
-** Created: Wed Sep 09 07:53:05 2004
+**   Created : Wed Sep 09 07:53:05 2004
+**        by : Varol Okan
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** Here we have a few global variables.
 **
 ****************************************************************************/
 
 #include "global.h"
+#include "cachethumbs.h"
 
 Log    *Global::pLogObject           = NULL;
 QString Global::qsProjectFileName    = QString (PROJECT_FILENAME);
@@ -15,15 +19,20 @@ QString Global::qsProjectName        = QString (PROJECT_NAME);
 QString Global::qsCurrentPath        = QString ("./");
 QString Global::qsBashString         = QString ("/bin/bash\n\n");
 QString Global::qsTempPath           = QString ("/tmp");
+QString Global::qsSystemPath         = QString ("/usr");
 QString Global::qsProjectPath        = QString ("");
 QString Global::qsExternalPlayer     = QString ("qplayer");
 QString Global::qsLanguage           = QString ("en");
-uint    Global::iMaxRunningThreads   = 4;
+QString Global::qsDefaultLanguage    = QString ("en");
+QString Global::qsDefaultFormat      = QString ("NTSC");
+uint    Global::iMaxRunningThreads   = 2;
 int     Global::iChildThreadPriority = 0;
 int     Global::iDeleteTempOlderThan = 30;
 QValueList <Utils::toolsPaths *> Global::listToolsPaths;
-MenuObject *Global::pCopyObject      = NULL;
-QEventLoop  Global::eventLoop;
+QDVDAuthor    *Global::pApp          = NULL;
+MenuObject    *Global::pCopyObject   = NULL;
+Cache::Thumbs *Global::pThumbsCache  = NULL;
+QEventLoop     Global::eventLoop;
 
 Global::Global()
 {
