@@ -50,7 +50,7 @@ bool Srt::readFile ( QString &fileName )
   QFile projectFile ( fileName );
   if (!projectFile.open ( IO_ReadOnly ) )
     return false;
-  
+
   QTextStream srtStream( &projectFile );
 
   lineIndex = srtStream.readLine();
@@ -66,6 +66,7 @@ bool Srt::readFile ( QString &fileName )
       lineIndex = srtStream.readLine();
   }
 
+  m_qsFileName = fileName;
   projectFile.close();
   return true;
 }
@@ -115,7 +116,7 @@ QString Srt::readEntry ( QTextStream *pStream, Subtitles::entry *pEntry )
 bool Srt::isTimeStamp ( QString &line )
 {
   line = line;
-  
+
   if ( ( line.find ("-->") > -1 ) && ( line.contains (':') >= 3) )
     return true;
   return false;
@@ -125,7 +126,7 @@ QString Srt::getTimeRange ( QString &line, bool bStartTime )
 {
   QString qsReturn;
   int iPos = line.find ( "-->" );
-  
+
   if ( iPos < 1 )
     return qsReturn;
   if ( bStartTime )
@@ -145,5 +146,9 @@ long Srt::getTimeFromString ( QString &qsTime )
   return iMSeconds;
 }
 
+QString Srt::getFileName ( )
+{
+  return m_qsFileName;
+}
 
 }; // End of namespace Import
