@@ -36,15 +36,18 @@ public:
    Srt ( );
   ~Srt ( );
 
-  bool    import    ( );
-  bool    readFile  ( QString & );
-  QString readEntry ( QTextStream *, Subtitles::entry * );
-  
+  bool    import      ( );
+  bool    readFile    ( QString & );
+  QString readEntry   ( QTextStream *, Subtitles::entry * );
+  QString getFileName ( );
+
   QValueList<Subtitles::entry *> m_listOfEntries;
 private:
   bool    isTimeStamp  ( QString &       );
   QString getTimeRange ( QString &, bool );
   long    getTimeFromString ( QString &  );
+
+  QString m_qsFileName;
 };
 
 }
