@@ -185,59 +185,68 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
 //		"+FILE_EXT+", "+AUDIO_FORMAT+", "+AUDIO_TYPE+", "+AUDIO_BITRATE+", "+SAMPLE_RATE+", "+STARTING_AT+", "+ENDING_AT+",
 //		"+DURATION+", "+WIDTH+", "+HEIGHT+", "+VIDEO_FORMAT+", "+VIDEO_TYPE+", "+VIDEO_BITRATE+", "+FRAME_RATE+", "+RATIO+",
 //		};
+  uint t;
+  // Build a local copy of values
+  QString stringArray[TransLast];
   QString qsRatio, qsValue, qsKey, qsOutput = qsInput;
   QString qsAudioBitrate, qsVideoBitrate;
-  uint t;
   long iAudioBitrate, iVideoBitrate, iStartingAt, iEndingAt, iDuration;
+
+  for (t=0;t<m_listOfPair[TransKeys].count();t++)	{
+    qsValue = value ( TransKeys, t );
+    stringArray[t] = qsValue;
+  }
+
   // Next we adjust it for the conversion tool.
 
   // These here are used for all conversion tools.
-  qsAudioBitrate = value ( TransKeys, TransAudioBitrate );
-  iAudioBitrate = qsAudioBitrate.toLong ( );
+  qsAudioBitrate = stringArray[ TransAudioBitrate ];
+  iAudioBitrate  = qsAudioBitrate.toLong ( );
   if ( iAudioBitrate > 10000 )
        iAudioBitrate = (int)( (float)iAudioBitrate / 1000.0);
   if ( iAudioBitrate <   32 )   // according to DVD spec this is the minimum.
        iAudioBitrate =  192;    // Note: How to handle no audio (0) ?
   if ( iAudioBitrate > 1536 )
        iAudioBitrate = 1536;   // This is the max rate according to DVD spec.
-  setValue ( TransKeys, TransAudioBitrate, QString ("%1").arg(iAudioBitrate) );
+  stringArray[ TransAudioBitrate ] = QString ("%1").arg ( iAudioBitrate );
 
-  qsValue     = value ( TransKeys, TransStartingAt );
+  qsValue     = stringArray [ TransStartingAt ];
   iStartingAt = qsValue.toLong ( );
-  qsValue     = value ( TransKeys, TransEndingAt );
+  qsValue     = stringArray [ TransEndingAt ];
   iEndingAt   = qsValue.toLong ( );
-  qsValue     = value ( TransKeys, TransDuration );
+  qsValue     = stringArray [ TransDuration ];
   iDuration   = qsValue.toLong ( );
   if ( iEndingAt < 20 )
        iEndingAt = 1000000000; // 1 Million Seconds approx. 9.3 hours
-  if ( iDuration < 20 )
-       iDuration = 1000000000; // 1 Million Seconds approx. 9.3 hours
   if ( iStartingAt > iEndingAt )
        iStartingAt = 0;
+  if ( iDuration < 20 )
+       iDuration = 1000000000; // 1 Million Seconds approx. 9.3 hours
+
   iStartingAt = (long)( iStartingAt / 1000.0 ); // convert form msec to seconds
   iEndingAt   = (long)( iEndingAt   / 1000.0 ); // convert from msec to seconds
   iDuration   = (long)( iDuration   / 1000.0 ); // convert form msec to seconds
-  setValue ( TransKeys, TransStartingAt, QString ( "%1" ).arg ( iStartingAt ) );
-  setValue ( TransKeys, TransEndingAt,   QString ( "%1" ).arg ( iEndingAt   ) );
-  setValue ( TransKeys, TransDuration,   QString ( "%1" ).arg ( iDuration   ) );
+  stringArray[ TransStartingAt] = QString ( "%1" ).arg ( iStartingAt );
+  stringArray[ TransEndingAt  ] = QString ( "%1" ).arg ( iEndingAt   );
+  stringArray[ TransDuration  ] = QString ( "%1" ).arg ( iDuration   );
 
-  qsValue = value ( TransKeys, TransAudioType );
+  qsValue = stringArray[ TransAudioType ];
   // default it to mp2 and only allow ac3, and pcm
   qsValue = qsValue.lower ( );
   if ( ( qsValue != "mp2" ) && ( qsValue != "pcm" ) )
          qsValue  = "ac3";
-  setValue ( TransKeys, TransAudioType, qsValue );
+  stringArray[ TransAudioType ] = qsValue;
 
-  qsVideoBitrate = value ( TransKeys, TransVideoBitrate );
-  iVideoBitrate = qsVideoBitrate.toInt ( );
+  qsVideoBitrate = stringArray[ TransVideoBitrate ];
+  iVideoBitrate  = qsVideoBitrate.toInt ( );
   if ( iVideoBitrate > 10000 )
        iVideoBitrate = (int)((float)iVideoBitrate / 1000.0 );
   if ( iVideoBitrate < 1856 )	// according to DVD spec this is the minimum.
        iVideoBitrate = 1856;	// Note: How to handle no audio (0) ?
-  setValue ( TransKeys, TransVideoBitrate, QString ("%1").arg( iVideoBitrate ) );
+  stringArray[ TransVideoBitrate ] = QString ("%1").arg( iVideoBitrate );
 
   if (qsConversionTool.find ( SUB_BLOCK_TRANSCODE ) > -1 )	{
-    qsRatio = value ( TransKeys, TransRatio );
+    qsRatio = stringArray[ TransRatio ];
     if ( qsRatio == QString ("1:1"))
       qsRatio = QString ("1");
     else if ( qsRatio == QString ("4:3"))
@@ -248,11 +257,11 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
       qsRatio = QString ("4");
     else 
       qsRatio = QString ("2");
-    setValue ( TransKeys, TransRatio, qsRatio );
+    stringArray[ TransRatio ] = qsRatio;
   }
   else if (qsConversionTool.find ( SUB_BLOCK_MENCODER ) > -1 )	{
     bool bOkay;
-    QString qsSampleRate = value ( TransKeys, TransSampleRate );
+    QString qsSampleRate = stringArray[ TransSampleRate ];
     int iSampleRate      = qsSampleRate.toInt ( &bOkay );
 
     if ( bOkay && ( iSampleRate < 10000 ) )
@@ -261,8 +270,8 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
       qsSampleRate =  "48000"; // default sample rate.
     else 
       qsSampleRate = QString ( "%1" ).arg ( iSampleRate );
-    setValue ( TransKeys, TransSampleRate, qsSampleRate );
-    qsRatio = value ( TransKeys, TransRatio );
+    stringArray[ TransSampleRate ] = qsSampleRate;
+    qsRatio = stringArray[ TransRatio ];
     if ( qsRatio == QString ("1:1"))
       qsRatio = QString ("1/1");
     else if ( qsRatio == QString ("4:3"))
@@ -273,25 +282,25 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
       qsRatio = QString ("2.21/1");
     else
       qsRatio = QString ("4/3");
-    setValue ( TransKeys, TransRatio, qsRatio );
+    stringArray[ TransRatio ] = qsRatio;
 
     // Next we take care of the end - pos ... 
-    QString qsEndPos = value ( TransKeys, TransEndingAt );
+    QString qsEndPos = stringArray[ TransEndingAt ];
     int iEndPos = qsEndPos.toInt ( &bOkay );
     if ( bOkay && iEndPos < 1 )
       qsEndPos = "100000000"; // 100000sec ~ 27:46h should be enough ...
 
     // And we also need to convert 29.97 to 30000/1001
-    QString qsFrameRate = value ( TransKeys, TransFrameRate );
+    QString qsFrameRate = stringArray[ TransFrameRate ];
     float fFrameRate = qsFrameRate.toFloat ( &bOkay );
     qsFrameRate = "30000/1001"; // default to 29.97 (ntsc)
     if ( ( bOkay ) && ( fFrameRate < 29.0 ) )
       qsFrameRate = "25";
-    setValue ( TransKeys, TransFrameRate, qsFrameRate );
+    stringArray[ TransFrameRate ] = qsFrameRate;
   }
   else if (qsConversionTool.find ( SUB_BLOCK_FFMPEG ) > -1 )	{
     bool bOkay;
-    QString qsSampleRate = value ( TransKeys, TransSampleRate );
+    QString qsSampleRate = stringArray[ TransSampleRate ];
     int iSampleRate      = qsSampleRate.toInt ( &bOkay );
 
     if ( bOkay && ( iSampleRate < 10000 ) )
@@ -300,31 +309,31 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
       qsSampleRate =  "48000"; // default sample rate.
     else
       qsSampleRate = QString ( "%1" ).arg ( iSampleRate );
-    setValue ( TransKeys, TransSampleRate, qsSampleRate );
+    stringArray[ TransSampleRate ] = qsSampleRate;
 
-    qsAudioBitrate = value ( TransKeys, TransAudioBitrate );
+    qsAudioBitrate = stringArray[ TransAudioBitrate ];
     iAudioBitrate = qsAudioBitrate.toInt ( &bOkay );
     if ( iAudioBitrate < 224000 )
          iAudioBitrate *=  1000;
     if ( iAudioBitrate < 224000 )
          iAudioBitrate = 224000;  // for ac3 minimum = 224kbps to 448kbps
-    setValue ( TransKeys, TransAudioBitrate, QString ("%1").arg( iAudioBitrate ) );
-    qsVideoBitrate = value ( TransKeys, TransVideoBitrate );
+    stringArray[ TransAudioBitrate ] = QString ("%1").arg( iAudioBitrate );
+    qsVideoBitrate = stringArray[ TransVideoBitrate ];
     iVideoBitrate  = qsVideoBitrate.toInt ( &bOkay );
     if ( iVideoBitrate < 1856000 ) // according to DVD spec this is the minimum.
          iVideoBitrate *=   1000;
     if ( iVideoBitrate < 1856000 )
          iVideoBitrate = 1856000;  // Minimum video Bitrate = 2800kbps
-    setValue ( TransKeys, TransVideoBitrate, QString ("%1").arg( iVideoBitrate ) );
+    stringArray[ TransVideoBitrate ] = QString ("%1").arg( iVideoBitrate );
   }
   else if (qsConversionTool.find ( SUB_BLOCK_VIDEOTRANS ) > -1 )	{
-    qsRatio = value ( TransKeys, TransRatio ); // only 4:3 and 16:9 are valid
+    qsRatio = stringArray[ TransRatio ]; // only 4:3 and 16:9 are valid
     if ( ( qsRatio != QString ("4:3") ) && ( qsRatio != QString ("16:9") ) )
-      setValue ( TransKeys, TransRatio, QString ( "4:3" ) );
+      stringArray[ TransRatio ] = QString ( "4:3" );
   }
 
   for (t=0;t<m_listOfPair[TransKeys].count();t++)	{
-    qsValue = value ( TransKeys, t );
+    qsValue = stringArray[ t ];
     qsKey   = key   ( TransKeys, t );
     // Here we replace the actual keyword with the real string.
     if ( ( qsValue.isNull()) || ( qsValue.isEmpty()) )
