@@ -21,12 +21,12 @@ public:
   enum enKeyBase { Keys, TransKeys, SubKeys, BaseLast };
 
   enum enTranscodeKeys {
-    TransDVDAuthorXML=0,   TransProjectPath, TransTempPath,    TransInputName , 
-    TransBaseName,         TransFileExt,     TransAudioFormat, TransAudioType, 
-    TransAudioBitrate,     TransSampleRate,  TransStartingAt,  TransEndingAt,
-    TransWidth,            TransHeight,      TransVideoFormat, TransVideoType, 
-    TransVideoBitrate,     TransFrameRate,   TransRatio,       TransAudioList, 
-    TransForEachCounter,   TransTrackName,   TransLast
+    TransDVDAuthorXML=0, TransProjectPath,    TransTempPath,    TransInputName , 
+    TransBaseName,       TransFileExt,        TransAudioFormat, TransAudioType, 
+    TransAudioBitrate,   TransSampleRate,     TransStartingAt,  TransEndingAt,
+    TransDuration,       TransWidth,          TransHeight,      TransVideoFormat,
+    TransVideoType,      TransVideoBitrate,   TransFrameRate,   TransRatio,
+    TransAudioList,      TransForEachCounter, TransTrackName,   TransLast
   };
   enum enKeys {
     KeyDVDAuthorXML=0,     KeyProjectPath,   KeyTempPath,      KeyWidth, 
@@ -38,7 +38,7 @@ public:
     SubProjectPath=0,  SubTempPath, SubInputFileName, SubXmlFile, SubBaseName,
     SubFileExt, SubSubtitleNumber, SubMultipleSubtitlePipe, SubLast
   };
-  
+
   class Entry {
   public:
      Entry  ( ) { iIndex = 0; };
