@@ -19,6 +19,8 @@
 #include <qfileinfo.h>
 #include <qdir.h>
 
+#include "CONFIG.h"
+
 #include "log.h"
 #include "global.h"
 #include "dvdmenu.h"
@@ -84,6 +86,12 @@ int main( int argc, char ** argv )
 #endif
 	QApplication application( argc, argv );
 
+#ifdef SYSTEM_DIRECTORY
+	Global::qsSystemPath = QString ( SYSTEM_DIRECTORY );
+#endif
+	if ( getenv ( "QDVD_SYSTEM_PATH" ) )
+		Global::qsSystemPath = getenv ( "QDVD_SYSTEM_PATH" );
+
 	Global::pThumbsCache = new Cache::Thumbs;
 
 	// translation file for Qt
@@ -94,10 +102,10 @@ int main( int argc, char ** argv )
 
 	QDVDAuthor dvdAuthor;
 	Global::pApp = &dvdAuthor;
-	VMGMenu *pDVDMenu = new VMGMenu (&dvdAuthor);
+	VMGMenu *pDVDMenu = new VMGMenu ( &dvdAuthor );
 
-	dvdAuthor.addDVDMenu(pDVDMenu, true);
-	dvdAuthor.show     ();
+	dvdAuthor.addDVDMenu ( pDVDMenu, true );
+	dvdAuthor.show ( );
 
 	CXmlDVDAuthor theXmlStructure;
 	QValueList<CXmlSpumux *>spumuxList;
@@ -153,11 +161,9 @@ int main( int argc, char ** argv )
 	  }
 	  break;  
 	  case 'x': { // execute without asking
-	    
 	  }
 	  break;
 	  case 'a': { // autmomatically create menus from input material
-	    
 	  }
 	  break;
 	  case 'o': { // save generated project file as ...
