@@ -30,6 +30,8 @@
 #include "shadowobject.h"
 #include "structuretoolbar.h"
 
+//void *g_pHelper = NULL;
+
 MenuObject::MenuObject (QWidget *pParent)
   : QObject (pParent)
 {
@@ -60,6 +62,8 @@ MenuObject::~MenuObject ()
   if ( m_pStructureItem )
     delete m_pStructureItem;
   m_pStructureItem = NULL;
+
+  m_pParent = NULL;
 }
 
 bool MenuObject::readProjectFile  (QDomNode &theNode)
@@ -257,7 +261,10 @@ void MenuObject::update ( )
 
 void MenuObject::resetStructureItem ( )
 {
-  if ( m_pStructureItem ) 
+  if ( m_pShadow )
+       m_pShadow->resetStructureItem ( );
+
+  if ( m_pStructureItem )
     delete m_pStructureItem;
   m_pStructureItem = NULL;
   m_modifiers.m_pStructureItem = NULL;
