@@ -484,7 +484,7 @@ void MenuPreview::slotPaste ( )
     for ( t=0; t<iCount; t++ ) {
       pNewObject = pCollection->getObject ( t )->clone ( this );
       paste ( pNewObject );
-    }      
+    }
   }
   else {
     pNewObject = Global::pCopyObject->clone ( this );
@@ -492,7 +492,6 @@ void MenuPreview::slotPaste ( )
   }
 }
 
-
 void MenuPreview::paste ( MenuObject *pNewObject )
 {
   QRegExp rx;
@@ -549,30 +548,30 @@ QString MenuPreview::getMovieFileName ( MovieObject * /*pMovieObject*/, QStringL
   return qsFullFileName;
 }
 
-void MenuPreview::dropEvent (QDropEvent *pDropEvent)
+void MenuPreview::dropEvent ( QDropEvent *pDropEvent )
 {
   QImage  theImage;
   QString theText;
   //  printf ( "%s::%s : %d  <%s>\n", __FILE__, __FUNCTION__, __LINE__, pDropEvent->format ( ) );
 
-  if (QImageDrag::decode(pDropEvent, theImage) )	{
-    if (theImage.isNull())
+  if ( QImageDrag::decode ( pDropEvent, theImage ) )  {
+    if ( theImage.isNull ( ) )
       return;
     // insert Image, movie or ButtonObject.
-    insertDraggedObject(pDropEvent, theImage);
+    insertDraggedObject ( pDropEvent, theImage );
     // And check if it comes with text or image only ...
-    if (QTextDrag::decode(pDropEvent, theText) ) 	{
-      insertDraggedText(pDropEvent, theText);
-      emit (signalDroppedSomething (DroppedImageAndText));
+    if (QTextDrag::decode ( pDropEvent, theText ) )  {
+      insertDraggedText   ( pDropEvent, theText );
+      emit ( signalDroppedSomething ( DroppedImageAndText ) );
     }
   }
   else if (QTextDrag::decode ( pDropEvent, theText ) ) 	{
     QString qsURL = theText;
-    qsURL = qsURL.remove ( "file://" );
-    theImage = QImage ( qsURL );
-    if ( theImage.isNull ( ) ) {
+    qsURL    = qsURL.remove ( "file://" );
+    theImage = QImage       ( qsURL );
+    if ( theImage.isNull    (   )   ) {
       // Insert TextObject
-      insertDraggedText(pDropEvent, theText);
+      insertDraggedText ( pDropEvent, theText );
       emit ( signalDroppedSomething ( DroppedText ) );
     }
     else {
@@ -700,10 +699,10 @@ MenuObject *MenuPreview::insertDraggedObject (QDropEvent *pDropEvent, QImage &th
 { 
 	MenuObject *pMenuObject = NULL;
 	// The first thing to check is if this drop was initiated in the Toolbar
-	if ( pDropEvent->source() && (QString("m_pListViewAllSources") == pDropEvent->source()->name()) )	{
-		ListViewMedia   *pListViewMedia   = (ListViewMedia *)pDropEvent->source();
-		SourceFileEntry *pSourceFileEntry = pListViewMedia->draggingSourceFileEntry();
-		SourceFileInfo  *pSourceFileInfo  = pListViewMedia->draggingSourceFileInfo();
+	if ( pDropEvent->source() && (QString("m_pListViewAllSources") == pDropEvent->source ( )->name ( ) ) )  {
+		ListViewMedia   *pListViewMedia   = (ListViewMedia *)pDropEvent->source      ( );
+		SourceFileEntry *pSourceFileEntry = pListViewMedia->draggingSourceFileEntry  ( );
+		SourceFileInfo  *pSourceFileInfo  = pListViewMedia->draggingSourceFileInfo   ( );
 		if ( pSourceFileEntry->bSoundSource )  {	// No adding of a sound source !
 			MessageBox::warning (NULL, tr("Can not add."), tr ("This is a sound source.\nI can currently not add this type of source.\n"), QMessageBox::Ok, QMessageBox::NoButton);
 			return NULL;
@@ -712,7 +711,7 @@ MenuObject *MenuPreview::insertDraggedObject (QDropEvent *pDropEvent, QImage &th
 			MessageBox::warning (NULL, tr("Can not add."), tr ("The slideshow is still beeing created.\nI can not add it at this moment.\n"), QMessageBox::Ok, QMessageBox::NoButton);
 			return NULL;
 		}
-		if ( pSourceFileInfo)	// Okay here we split between adding one button
+		if ( pSourceFileInfo )  // Okay here we split between adding one button
 			pMenuObject = insertDraggedSourceInfo  (pDropEvent, theImage);	// ButtonObject
 		else	// Or we dragged the full SourceEntry and will use the defined Layout
 			if (pSourceFileEntry->listFileInfos.count() == 1) // Now only one movie in the Entry ... Booooring ...
@@ -736,12 +735,12 @@ MenuObject *MenuPreview::insertDraggedSourceEntry(QDropEvent *pDropEvent, QImage
 	uint t;
 	ObjectCollection *pObjectCollection = new ObjectCollection;
 	// The wizard will take care of the spacing plus the overlay
-	LayoutWizard *pWizard = new LayoutWizard;
+	LayoutWizard    *pWizard = new LayoutWizard;
 
-	ButtonObject *pButtonObject = NULL;
+	ButtonObject    *pButtonObject    = NULL;
 	// Note that at this point we KNOW that the source is coming from the ListViewAllSources - toolbar !!!
-	ListViewMedia *pListViewMedia = (ListViewMedia *)pDropEvent->source();
-	SourceFileEntry *pSourceFileEntry = pListViewMedia->draggingSourceFileEntry();
+	ListViewMedia   *pListViewMedia   = (ListViewMedia *)pDropEvent->source     ( );
+	SourceFileEntry *pSourceFileEntry = pListViewMedia->draggingSourceFileEntry ( );
 	SourceFileInfo  *pSourceFileInfo  = NULL;
 
 	for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
@@ -858,7 +857,7 @@ MenuObject *MenuPreview::insertDraggedChapter ( QDropEvent *pDropEvent, QIconVie
   // Next we give some color the the diffenrent states
   pNewSelected   ->setFrameColor ( colorSelected      );
   pNewHighlighted->setFrameColor ( colorHighlighted   );
-  
+
   pButtonObject->appendNormal      ( pMenuObject      );
   pButtonObject->appendSelected    ( pNewSelected     );
   pButtonObject->appendHighlighted ( pNewHighlighted  );
@@ -1019,7 +1018,8 @@ MenuObject *MenuPreview::insertDraggedSourceInfo(QDropEvent *pDropEvent, QImage
 	undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::DRAGGED_BUTTON, pButtonObject));
 
 	emit (signalUpdateStructure());
-	updatePixmap();
+	updatePixmap ( );
+	m_pActiveObject = pButtonObject;
 	return pButtonObject;
 }
 
@@ -1424,7 +1424,7 @@ MenuObject *MenuPreview::createImageObject(bool bShowDialog)
 	    return NULL;
 
 	  QFileInfo fileInfo  (qsImageName);
-	  Global::qsCurrentPath = fileInfo.filePath();
+	  Global::qsCurrentPath = fileInfo.dirPath ( TRUE );
 
 	  // Here we create the Pixmap in the right scale
 	  QImage theImage (qsImageName);
@@ -1468,7 +1468,7 @@ MenuObject *MenuPreview::createMovieObject(bool bShowDialog)
     // to speed things up we create a dummyMediaInfo first
     MediaInfo *pMediaInfo = (MediaInfo *) new DummyInfo ();
     QString qsFilter = tr ("Movie Files (%1)").arg(pMediaInfo->getExtensions (true));
-    
+
     //QString qsMovieName = QFileDialog::getOpenFileName(Global::qsCurrentPath, qsFilter, this, 
     //	tr("Select movie"), tr("Select a movie object."));
     QString qsMovieName = FilePreviewDialog::getOpenFileName ( NULL, Global::qsCurrentPath, QString ("Movies ( ") + qsFilter + QString (" );;All ( * )"), this, tr ( "Select image" ), tr ( "Select a image object." ) );
@@ -1478,13 +1478,13 @@ MenuObject *MenuPreview::createMovieObject(bool bShowDialog)
     setCursor (myCursor);
     // Here we need to get a screenshot, thus the dummy won't do !!!
     delete pMediaInfo;
-    
+
     QFileInfo fileInfo  (qsMovieName);
-    Global::qsCurrentPath = fileInfo.filePath();
-    
+    Global::qsCurrentPath = fileInfo.dirPath ( TRUE );
+
     // Here we create the Pixmap in the right scale
     QImage theImage = QImage().fromMimeSource("please_wait.jpg");
-    
+
     int   iHeight;
     QSize theSize = m_rectCurrentObject.size();
     theImage = theImage.smoothScale (theSize, QImage::ScaleFree);
@@ -1502,17 +1502,17 @@ MenuObject *MenuPreview::createMovieObject(bool bShowDialog)
     pMovieObject->setFile     (qsMovieName);
     pMovieObject->setPixmap   (thePixmap);
     pMovieObject->setMovieSize(theSize);
-    
+
     m_listMenuObjects.append  ( pMovieObject );
     emit ( signalUpdateStructure ( ) );
     updatePixmap ( );
-    
+
     // Next we register to receive a preview image of the movie file ...
     MediaCreator::registerWithMediaScanner (pMovieObject, qsMovieName, pMovieObject->previewImage());
-    
+
     // We need this to obtain a pointer to the assoziated DVDMenu ...
     emit (signalCreatedMovieObject (pMovieObject, true)); // inclusive render request ...
-    
+
     myCursor = QCursor(QCursor::ArrowCursor);
     setCursor (myCursor);
   }
@@ -1521,7 +1521,7 @@ MenuObject *MenuPreview::createMovieObject(bool bShowDialog)
     // We need this to obtain a pointer to the assoziated DVDMenu ... But no render request ...
     emit (signalCreatedMovieObject (pMovieObject, false));
   }
-  
+
   // And last we connect the signals
   connectStdSlots ( pMovieObject, true );
   return pMovieObject;
@@ -1536,7 +1536,7 @@ MenuObject *MenuPreview::createButtonObject(bool bShowDialog)
     emit (signalUpdateStructure());
     updatePixmap();
   }
-  
+
   // And finally we connect everything ...
   connectStdSlots ( pButtonObject, true );
   return pButtonObject;
@@ -1606,7 +1606,7 @@ ButtonObject *MenuPreview::defineAsButton ( MenuObject *pTheObject, bool bShowDi
 		((TextObject *)(pNewSelected))   ->modifiers()->fTransparency = 0.0f;
 		((TextObject *)(pNewHighlighted))->modifiers()->fTransparency = 0.0f;
 	}
-	else	{	// All but Text Objects get a frame for starters
+	else	{// All but Text Objects get a frame for starters
 		// Okay we want 1:1 for FrameObjects
 		if (pTheObject->objectType() == frameObject.objectType())	{
 			pNewSelected    = pTheObject->clone();
@@ -1732,12 +1732,12 @@ void MenuPreview::slotUpdatePixmap ( )
   updatePixmap ( );
 }
 
-void MenuPreview::slotDeleteObject(MenuObject *pObject)
+void MenuPreview::slotDeleteObject ( MenuObject *pObject )
 {
 	// simply do the same as the base class but also update the structureView ...
-	ButtonPreview::slotDeleteObject(pObject);
-	updatePixmap();
-	emit (signalUpdateStructure());
+	ButtonPreview::slotDeleteObject ( pObject );
+	updatePixmap ( );
+	emit ( signalUpdateStructure ( ) );
 }
 
 void MenuPreview::slotAddShadow ( MenuObject *pObject ) 
@@ -1752,13 +1752,13 @@ void MenuPreview::slotAddShadow ( MenuObject *pObject )
   if ( pObject == &m_selectionObject ) {
     for ( uint t=0; t<m_listMenuObjects.count ( ); t++ )  {
       if ( ! m_selectionObject.contains ( m_listMenuObjects.at ( t ) ) )
-	m_listMenuObjects.at ( t )->drawContents ( &thePainter );
+             m_listMenuObjects.at ( t )->drawContents ( &thePainter );
     }
   }
   else {
     for (  uint t=0; t<m_listMenuObjects.count ( ); t++ )  {
       if ( m_listMenuObjects.at ( t ) != pObject )
-	m_listMenuObjects.at ( t )->drawContents ( &thePainter );
+           m_listMenuObjects.at ( t )->drawContents ( &thePainter );
     }
   }
 
@@ -1914,7 +1914,7 @@ void MenuPreview::slotUnbutton ( ButtonObject *pButton )
   }
   // Finally we can delete the button object.
   delete pButton;
-  
+
   emit ( signalUpdateStructure ( ) );
 }
 
