@@ -988,7 +988,11 @@ void OneClickWizard::slideshowToPlugin ( Plugin::SourceGroup *pGroup, CXmlSlides
   pGroup->bCreateChapterMenu  = false;
   pGroup->iFilterLength       = (int)( pSlideshow->filter_delay * 1000.0f );
   pGroup->qsBackground        = pSlideshow->background;
+  pGroup->listFilter          = pSlideshow->validFilterNames;
   pGroup->listAudio           = pSlideshow->audio_list;
+  pGroup->iFlags  =   pSlideshow->imgBkgImg ( ) ? 1 : 0;
+  pGroup->iFlags |=   pSlideshow->intro_page    ? 2 : 0;
+  pGroup->iFlags |= ( pSlideshow->yres == 576 ) ? 4 : 0;
 
   // The following is currently not used ...
   pGroup->dateStart           = QDateTime ( date, time );
