@@ -266,7 +266,8 @@ bool ComplexDVD::execute ( )
     iMenuNumber ++;
   }
 
-  int iProgress = 0;
+  int iProgress   = 0;
+  int iSlideCount = 1;
   QDialog   progressDialog    ( NULL );
   QGridLayout  progressLayout ( &progressDialog );
   QProgressBar progressBar    ( &progressDialog );
@@ -287,7 +288,7 @@ bool ComplexDVD::execute ( )
     listGroups.append ( pGroup );
     if ( iCount++ >= iButtonsPerMenu - 1 )  {
       SourceGroup::type theType = pGroup->enType;
-      QString qsMenuXML = getMenuXML ( listGroups, ++iMenuNumber );
+      QString qsMenuXML = getMenuXML ( listGroups, ++iMenuNumber, iSlideCount );
       listGroups.clear ( );
 
       QString qsMenuName = QString ( "Menu %1" ).arg ( iMenuNumber );
@@ -304,7 +305,7 @@ bool ComplexDVD::execute ( )
       SourceGroup::type theType = pGroup->enType;
       QString qsMenuName, qsMenuXML;
       qsMenuName.sprintf ( "Menu %d", ++iMenuNumber );
-      qsMenuXML = getMenuXML ( listGroups, iMenuNumber );
+      qsMenuXML = getMenuXML ( listGroups, iMenuNumber, iSlideCount );
       listGroups.clear ( );
 
       // Create the DVDMenu
@@ -315,13 +316,13 @@ bool ComplexDVD::execute ( )
   return true;
 }
 
-QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber )
+QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber, int &iSlideCount )
 {
   QFileInfo fileInfo;
   QString qsMenuXML, qsBackgroundFile, qsMenuName, qsFileName, qsGroupName;
   QString qsHeight = "480";
   QString qsButtonName, qsFrameName, qsObjectName, qsJumpTo, qsX, qsY, qsTempPath;
-  int iCount = 0, iSlideCount = 1;
+  int iCount = 0;
   SourceGroup *pGroup = NULL;
   if ( list.count ( ) < 1 )
     return qsMenuXML;
