@@ -58,7 +58,7 @@ protected slots:
   virtual void slotHDRCreme     ( bool );
 
 protected:
-  QString getMenuXML     ( QValueList<SourceGroup *> &, int );
+  QString getMenuXML     ( QValueList<SourceGroup *> &, int, int & );
   QString getMenuButtons ( bool, bool, int );
   QString getImgCmd      ( QString & );
   void    getRandomBackground ( );
