@@ -28,9 +28,16 @@ MenuSlideInterface::MenuSlideInterface ( )
 
 }
 
-void MenuSlideInterface::doEmit ( Interface::enResponseType, QString &qsMenuName, QString &qsText )
+bool MenuSlideInterface::execute  ( )
 {
-  emit ( signalPluginResponse ( Plugin::Interface::NTSCMenuResponse, qsMenuName, qsText ) );
+  MenuSlide::show ( );
+  return true;
+};
+
+void MenuSlideInterface::doEmit ( SourceGroup::type theType, QString &qsMenuName, QString &qsText )
+{
+  emit ( signalNewMenuResponse ( theType, qsMenuName, qsText ) );
+//  emit ( signalPluginResponse ( Plugin::Interface::NTSCMenuResponse, qsMenuName, qsText ) );
 }
 
 MenuSlide::ImageContainer::ImageContainer ( QString &qsFile )
@@ -66,11 +73,6 @@ MenuSlide::~MenuSlide ( )
 {
 }
 
-void MenuSlide::initMe ( QObject * )
-{
-  uiDialogMenuSlide::show ( );
-}
-
 void MenuSlide::polish ( )
 {
   uiDialogMenuSlide::polish ( );
@@ -349,7 +351,7 @@ void MenuSlide::animate ( unsigned long iFrameNumber )
       iImageWidth  = (int)( fDeltaZoom * iFrameNumber * iWidth  );
       iImageHeight = (int)( fDeltaZoom * iFrameNumber * iHeight );
       theImage     = m_listImages[t]->thumbnail.smoothScale ( iWidth, iHeight, QImage::ScaleMin );
-      
+
       thePainter.drawImage ( 20, 20, theImage );
     }
   }
@@ -405,9 +407,9 @@ void MenuSlide::accept ( )
   QString qsText = getMenuXml ( );
   QString qsMenuName ( "MenuSlide" );
 
-  Plugin::Interface::enResponseType theType = Plugin::Interface::NTSCMenuResponse;
+  Plugin::SourceGroup::type theType = Plugin::SourceGroup::NTSC;
   if ( m_pComboFormat->currentItem ( ) > 0 )
-    theType = Plugin::Interface::PALMenuResponse;
+    theType = Plugin::SourceGroup::PAL;
 
   doEmit ( theType, qsMenuName, qsText );
   //printf ( "Accepted <%s>\n", qsText.ascii( ) );
