@@ -47,7 +47,7 @@ public:
   virtual bool execute ( );
 
 protected:
-  QString getMenuXML     ( QValueList<SourceGroup *> &, int );
+  QString getMenuXML     ( QValueList<SourceGroup *> &, int, int & );
   QString getMenuButtons ( bool, bool, int );
 
   int m_iNrOfMenus;
