@@ -18,7 +18,7 @@ class SourceGroup
       bool       bVidSource;
       unsigned long iLength; // in MSec
     };
-             SourceGroup ( ) { enType=NTSC; bSlideshow=false; bCreateChapterMenu=false; };
+             SourceGroup ( ) { enType=NTSC; bSlideshow=false; bCreateChapterMenu=false; iFlags=2; };
     virtual ~SourceGroup ( ) {
       QValueList<SourceEntry *>::iterator it=listFiles.begin ( );
       while ( it != listFiles.end ( ) )
@@ -38,7 +38,9 @@ class SourceGroup
     bool        bSlideshow;
     int         iFilterLength;
     QString     qsBackground;
+    QStringList listFilter;
     QStringList listAudio;
+    uint        iFlags;  // For Slideshow : holds Format, IntroPage, bImgBkgImg
 }; // end class SourceGroup
 
 }; // end namespace Plugin
