@@ -45,9 +45,9 @@ class DialogLibrary;
 class TemplateWizard;
 class CXmlDVDAuthor;
 class CXmlSpumux;
+namespace DVDLayout { class Gui; };
 
 #define DVDAUTHOR_XML "dvdauthor.xml"
-#define SUBTITLES_TAB "Subtitles"
 
 #include "rgba.h"
 #include "utils.h"
@@ -58,6 +58,8 @@ class QDVDAuthor : public CFormMain
 	Q_OBJECT
 
 public:
+	enum enTabs { TabMainMenu=0, TabSubMenu, TabSubtitles, TabDVDLayout, TabDVDAuthorXml };
+
 	QDVDAuthor ( );
 	virtual ~QDVDAuthor ( );
 
@@ -90,6 +92,7 @@ public slots:
 	virtual void slotPluginCallback  ( int, QString, QString );
 	virtual void slotNewMenuResponse ( int, QString, QString );
 	virtual void slotNewSource       ( Plugin::SourceGroup * );
+	virtual void slotEnableTabs             (  int );
 	virtual void slotChangeLanguage         (  int );
 	virtual void slotVisibleRegion          ( bool );
 	virtual void slotSetup                       ( );
@@ -114,6 +117,7 @@ public slots:
 	virtual void slotCloneCurrentSubMenu         ( );
 	virtual void slotUndoStack                   ( );
 	virtual void slotUpdateStructure             ( );
+	virtual void slotUpdateDVDLayout             ( );
 	virtual void slotDeleteTempOlderThan         ( );
 	virtual void slotCreateXml   ( const QString & );
 	virtual void slotUpdateMenuBar               ( );
@@ -136,6 +140,7 @@ public:
 	void addDVDMenu           ( DVDMenu *, bool b=false );
 	void returnFromRenderMenu ( );
 	bool checkForNewProject   ( );
+	bool tabVisible           ( enTabs );
 
 	int  getFreeSourceSlot                                ( );
 	void addMovieList      ( QStringList &, QString *p=NULL );
@@ -154,7 +159,8 @@ public:
 	void updateStatusColor                                ( ); // updates the SourceToolBar color's
 	MediaInfo *getMediaInfo                               ( );
 	DragNDropContainer *getDragNDropContainer             ( );
-	
+
+	DVDMenu *findMenuFromSourceFileEntry( SourceFileEntry * );
 	DVDMenu         *getCurrentSubMenu                    ( );
 	DVDMenu         *getSubMenuByName             ( QString );
 	DVDMenu         *getVMGMenu                           ( );
@@ -167,21 +173,23 @@ public:
 	QString getMovieFilter      ( );
 	QString getSoundFilter      ( );
 
-private: 	// Private functions ...
+private: // Private functions ...
 	void initMe                 ( );
 	bool cleanUp                ( );
 	void LoadIni                ( );
 	void SaveIni                ( );
 	void newWizard              ( );
 	void buildHistoryEntries    ( );
-	void updateHistoryPix       (  );
+	void updateHistoryPix       ( );
+	void initTabs               ( );
 	void initPlugins            (   );
 	void initLanguages          (     );
 	void initStyles             (       );
-	void initSubtitlesTab       (         );
-	void addHistory             ( QString   );
-	bool writeProjectFile       ( QDomElement &);
-	void setAutosave            ( bool b=false   );
+	void initDVDLayoutTab       (         );
+	void initSubtitlesTab       (           );
+	void addHistory             ( QString     );
+	bool writeProjectFile       ( QDomElement & );
+	void setAutosave            ( bool b=false    );
 	bool readProjectFile        ( QDomNode &, float & );
 	bool renderSubtitles        ( SourceFileInfo *, bool b=false );
 	bool buildFromDvdauthorXML  ( CXmlDVDAuthor *, QValueList<CXmlSpumux *> & );
@@ -192,13 +200,15 @@ private: 	// Private functions ...
 	void createDVD              ( );
 	bool checkHealth            ( );
 	void engageCreateDVD        ( bool ); // Called to put QDVDAuthor in wait mode for slideshows to finish
+	void replaceTempPaths       ( QString );
 	QString getTempFile         ( QString );
+	QWidget *getTabWidget       ( enTabs, int i=0 );
 
 private:
 	bool    m_bVisibleRegion;
 
 	DVDMenu *m_pVMGMenu;
-	QValueList<DVDMenu *>	m_listDVDMenus;
+	QValueList<DVDMenu *>   m_listDVDMenus;
 	DragNDropContainer      m_dragNDropContainer;
 	QStringList             m_listHistory;
 	QValueList<QPixmap *>   m_listHistoryPix;
@@ -213,12 +223,14 @@ private:
 	ColorToolBar           *m_pColorToolbar;
 	SourceToolBar          *m_pSourceToolbar;
 	StructureToolBar       *m_pStructureToolbar;
+	DVDLayout::Gui         *m_pDVDLayoutGui;
 	SubtitlesGui           *m_pSubtitlesGui;
 	QPopupMenu             *m_pMenuHistory;
 	bool                    m_bModified;
 	QTranslator            *m_pTranslator;
 	QPopupMenu             *m_pLanguagePopup;
 	QPopupMenu             *m_pPluginsPopup;
+	QPopupMenu             *m_pTabsPopup;
 	QPopupMenu             *m_pStylesPopup;
 	DialogExecute          *m_pDialogExecute;
 	DialogLibrary          *m_pDialogLibrary;
@@ -231,6 +243,7 @@ private:
 	QAction  *m_pActionToolbarSave;
 	QAction  *m_pActionToolbarSaveAs;
 	QAction  *m_pActionToolbarExit;
+	QWidget  *m_mainTabBuffer[3];  // DVDLayout/Subtitles/XMLOut
 };
 
 #endif // QDVDAUTHOR_H
