@@ -65,6 +65,7 @@
 #define ATTRIB_MAX_THREADS       "max_threads"
 #define ATTRIB_DELETE_OLDER_THAN "delete_older_than"
 #define ATTRIB_VISIBLE_REGION    "visible_region"
+#define ATTRIB_TABS              "tabs"
 #define ATTRIB_NUMBER            "number"
 #define ATTRIB_HIDDEN            "hidden"
 #define ATTRIB_EDITABLE          "editable"
@@ -158,6 +159,7 @@ public:
 
 	QString preferredEngine ( );
 	bool    visibleRegion   ( );
+	bool    visibleTabs(  int );
 	void setToolsPaths ( QValueList<Utils::toolsPaths *>& );
 	QValueList <Utils::toolsPaths *> &getToolsPaths     ( );
 	QValueList <ExecuteInterface *>  &getList           ( );
@@ -173,6 +175,7 @@ public:
 	void setTemplateContact       ( QString & );
 	void setAutosave              ( int  );
 	void setVisibleRegion         ( bool );
+	void setVisibleTabs           ( int, bool );
 	void setHistory               ( int, QStringList, QValueList<QPixmap *> );
 	void appendPreProcessing      ( );
 	void appendConvert            ( SourceFileEntry * );
@@ -209,6 +212,7 @@ private:	// private functions.
 
 private:	// private variables
 	QString              m_qsPreferredEngine;
+	bool                 m_bActivateTabs[3]; // DVDLayout/Subtitle/XMLOut
 	bool                 m_bVisibleRegion;
 	bool                 m_bProtectToolsObjects;
 	bool                 m_bFirstApplicationStart;
