@@ -18,7 +18,7 @@
 class MPlayerWidget : protected QMPlayerWidget, public MediaInterface
 {
 public:
-	MPlayerWidget(QWidget *p=0, const char *n=0, void *p=NULL);
+	MPlayerWidget(QWidget *p=0, const char *n=0, void *p2=NULL);
 	virtual ~MPlayerWidget();
 
 	// Here are the implementation of the mandatory MediaInterface - class
@@ -37,6 +37,11 @@ public:
 	virtual void setPosition       (uint);
 	virtual void setPositionByTime (uint);
 
+	virtual void setNavigate( enNavigate );
+	virtual void setMenu        ( enMenu );
+	virtual void setSubtitleTrack  ( int );
+	virtual void setAudioTrack     ( int );
+
 	virtual float volume               ();
 	virtual float position             ();
 	virtual QImage getScreenshot       ();
