@@ -61,7 +61,8 @@ QMPlayerWidget::~QMPlayerWidget ( )
   if ( m_pMasterProcess ) {
     if ( m_pMasterProcess->processIdentifier ( ) > 0 ) {
       QString qsCommand = QString ( "kill -9 `ps -ef | grep -e mplayer -e %1 | awk '{print $2}'`" ).arg ( winId ( ) ); 
-      system ( qsCommand.ascii ( ) );
+      int iRet = system ( qsCommand.ascii ( ) );
+      iRet = iRet;
     }
     if ( m_pMasterProcess->isRunning ( ) )
       m_pMasterProcess->kill   ( );
@@ -154,9 +155,10 @@ void QMPlayerWidget::loadInitFile ()
 	QDomDocument xmlDoc( XML_DOCTYPE_MPLAYER );
 	if (!xmlDoc.setContent (&iniFile))	{
 		// Error handling ...
-		iniFile.close();
-		printf ( (const char *) QObject::tr ("MPlayer xml init file <%1> seems to be defective. Re-setting values.\n").arg(qsPlayerIniFile));
- 		saveInitFile();
+		iniFile.close ( );
+		QString qsOut = QObject::tr ( "MPlayer xml init file <%1> seems to be defective. Re-setting values.\n" ).arg( qsPlayerIniFile );
+		printf ( "%s", qsOut.ascii ( ) );
+ 		saveInitFile ( );
 		return;
 	}
 
