@@ -1,8 +1,10 @@
 /****************************************************************************
 ** MediaInfo - class
 **
-** Created: Tue Nov 9 12:09:08 2004
-**      by: Varol Okan using kate editor
+**   Created : Tue Nov 9 12:09:08 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class will use the Media Engine (Xine, MPlayer, or VLC), to obtain 
 ** information about the stream currently set by this engine.
@@ -23,7 +25,7 @@ public:
 
 	void   *getMediaEngine  ();
 	void    setMediaEngine  (void *);
-	void    setFileName     (QString );
+	void    setFileName     (QString, bool b=true );
 	QString getFileName     (bool b=true);
 
 	unsigned long int getLength ();
@@ -56,6 +58,11 @@ public:
 	// Non mandatory overloaded functions
 	virtual QString getExtensions (bool b=true);
 
+	// Some housekeeping stuff
+	// Required for MPlayerInfo. MainThread must use EventLoop, worker thread must not have an eventLoop.
+	bool useEventLoop    ( );
+	void setUseEventLoop ( bool );
+
 protected:
 	void initMe ();
 	virtual void queryValues () = 0;
@@ -66,6 +73,7 @@ protected:
 protected:
 	void   *m_pMediaEngine;
 	bool    m_bHaveValues;
+	bool    m_bUseEventLoop;
 
 	bool    m_bHasAudio;
 	bool    m_bHasVideo;
