@@ -72,7 +72,9 @@ QString QRender::checkForExe( QString qsExe )
 	QString qsExePath;
 	QFileInfo fileInfo(QString ("/tmp/%1_out.txt").arg(getlogin()));
 	// the next check is to see if we can find 
-	system ((const char *)QString ("which %1 > /tmp/%2_out.txt 2>/dev/null").arg(qsExe).arg(getlogin()));
+	int iRet = system ((const char *)QString ("which %1 > /tmp/%2_out.txt 2>/dev/null").arg(qsExe).arg(getlogin())); 
+	iRet = iRet;
+
 	fileInfo.setFile(QString("/tmp/%1_out.txt").arg(getlogin()));
 	// Okay we can not find it, so we wont bother asking the user ...
 	if (fileInfo.size() > 4)	{
@@ -144,10 +146,11 @@ void QRender::transcode ()
 printf ("transcode :\n%s\n\n", (const char *)qsConversionScript);
 	generateFile (qsFileName, qsConversionScript);
 	chmod  (qsFileName, S_IEXEC | S_IRUSR | S_IWRITE);
-	system (qsCommand);
+	int iRet = system (qsCommand);
+	iRet = iRet;
 	for (t=0;t<m_xmlQRender.qrender().mmm.listOfClips.count();t++)	{
 		qsCommand = QString ("convert.sh");
-		system (qsCommand);
+		iRet = system (qsCommand);
 	}
 }
 
