@@ -225,9 +225,13 @@ QStringList &Manager::getFilterNames ( )
 
   qsCommand = theUtils.getToolPath ( "qrender" );
   if ( qsCommand.isEmpty ( ) )  {
-    qsCommand = theUtils.checkForExe ( "qrender" );
-    if ( qsCommand.isEmpty ( ) )
-         qsCommand = "qrender";
+    qsCommand = Global::qsSystemPath + "/bin/qrender";
+    QFileInfo fileInfo ( qsCommand );
+    if ( ! fileInfo.exists ( ) )  {
+      qsCommand = theUtils.checkForExe ( "qrender" );
+      if ( qsCommand.isEmpty ( ) )
+           qsCommand = "qrender";
+    }
   }
   m_listFilterNames.clear ( );
 
@@ -716,9 +720,13 @@ void Client::startServer ( )
   Utils theUtils;
   QString qsCommand = theUtils.getToolPath ( "qrender" );
   if ( qsCommand.isEmpty ( ) )  {
-    qsCommand = theUtils.checkForExe ( "qrender" );
-    if ( qsCommand.isEmpty ( ) )
-         qsCommand = "qrender";
+    qsCommand = Global::qsSystemPath + "/bin/qrender";
+    QFileInfo fileInfo ( qsCommand );
+    if ( ! fileInfo.exists ( ) )  {
+      qsCommand = theUtils.checkForExe ( "qrender" );
+      if ( qsCommand.isEmpty ( ) )
+           qsCommand = "qrender";
+    }
   }
   qsCommand += " -v 5";
   int iRet = system ( qsCommand.ascii ( ) );
