@@ -161,7 +161,8 @@ ShadowObject::ShadowObject ( MenuObject *pMenuObject, QWidget *pParent )
   }
 
   if ( ! m_pMenuObject )
-         m_pMenuObject   = pMenuObject;
+         m_pMenuObject = pMenuObject;
+
   m_iDeltaX       =    -1;
   m_iDeltaY       =    -1;
   m_fSunAngle     =  0.0f;
@@ -180,7 +181,8 @@ ShadowObject::ShadowObject ( MenuObject *pMenuObject, QWidget *pParent )
 
 ShadowObject::~ShadowObject ( ) 
 {
-
+  m_pMenuObject    = NULL;
+  m_pStructureItem = NULL;
 }
 
 ShadowObject &ShadowObject::operator = ( ShadowObject &theOther )
@@ -263,16 +265,16 @@ void ShadowObject::drawShadow ( QPainter *pPainter )
   centerPos.setY ( objectRect.y ( ) + (int) ( (float) objectRect.height ( ) / 2.0 ) );
   // Here we define the cenetered rect.
   QRect theRect ((int)-( objectRect.width ( ) / 2.0), (int)-( objectRect.height ( ) / 2.0 ), objectRect.width ( ), objectRect.height ( ) );
-  
+
   // From the Qt documentation ...
   // This transformation engine is a three-step pipeline
   // The first step uses the world transformation matrix.
   // The second step uses the window.
   // The third step uses the viewport.
-  
+
   // First we translate to the appropriate location,
   theMatrix.translate ( (double)centerPos.x ( ), (double)centerPos.y ( ) );
-  
+
   // then we apply the other modifications ...
   theMatrix.scale  ( pModifiers->fScaleX, pModifiers->fScaleY );
   theMatrix.shear  ( pModifiers->fShearX, pModifiers->fShearY );
@@ -321,7 +323,7 @@ void ShadowObject::drawMirror ( QPainter *pPainter )
 
   // First we translate to the appropriate location,
   theMatrix.translate ( (double)iX, (double)iY );
-  
+
   // then we apply the other modifications ...
   theMatrix.scale  ( pModifiers->fScaleX, pModifiers->fScaleY );
   theMatrix.shear  ( pModifiers->fShearX, pModifiers->fShearY );
@@ -349,7 +351,7 @@ void ShadowObject::drawContents ( QPainter *pPainter, int iRenderFrameNumber, in
   // And then we ought to refresh the pixmap ...
   if ( m_listAnimationAttributes.count () > 0 )
     updateShadow ( true );
-  
+
   drawContents ( pPainter );
 }
 
@@ -358,12 +360,12 @@ bool ShadowObject::mousePressEvent ( QMouseEvent   * )
   return false;
 }
 
-bool ShadowObject::mouseReleaseEvent ( QMouseEvent   * )
+bool ShadowObject::mouseReleaseEvent ( QMouseEvent * )
 {
   return false;
 }
 
-bool ShadowObject::mouseDoubleClickEvent ( QMouseEvent   * )
+bool ShadowObject::mouseDoubleClickEvent ( QMouseEvent * )
 {
   return false;
 }
@@ -377,9 +379,9 @@ StructureItem *ShadowObject::createStructure ( StructureItem *pParentItem )
        qsItem    = tr   ( "Mirror Object" );
   QString qsName = qsItem;
   QString qsInfo (   tr ( "Shadow dist=%1 blur=%2 angle=%3 transparency=%4").
-		    arg ( distance ( ) ).arg ( blur         ( ) ).
-		    arg ( sunAngle ( ) ).arg ( transparency ( ) ) );
-  
+                    arg ( distance ( ) ).arg ( blur         ( ) ).
+                    arg ( sunAngle ( ) ).arg ( transparency ( ) ) );
+
   pShadowItem = m_pStructureItem;
   if ( ! pShadowItem ) {
     pShadowItem = new StructureItem ( this, pParentItem, pParentItem->lastChild ( ), qsName, qsInfo );
@@ -390,7 +392,7 @@ StructureItem *ShadowObject::createStructure ( StructureItem *pParentItem )
     pShadowItem->setText ( qsName, qsInfo );
 
   QString qsArgs;
-  
+
   pTemp  = pShadowItem->setSibling ( this, pTemp, tr ( "Sun Angle"    ), QString ( "%1" ).arg ( sunAngle ( ) ) );
   pTemp  = pShadowItem->setSibling ( this, pTemp, tr ( "Distance"     ), QString ( "%1" ).arg ( distance ( ) ) );
   pTemp  = pShadowItem->setSibling ( this, pTemp, tr ( "Blur Radius"  ), QString ( "%1" ).arg ( blur     ( ) ) );
@@ -399,7 +401,7 @@ StructureItem *ShadowObject::createStructure ( StructureItem *pParentItem )
   if ( theType == TYPE_MIRROR ) {
     qsArgs = QString ( "%1, Color(%2, %3, %4)").arg ( sunAngle ( ) ).
                       arg ( m_colorFadeTo.red   ( ) ).
-		      arg ( m_colorFadeTo.green ( ) ).
+                      arg ( m_colorFadeTo.green ( ) ).
                       arg ( m_colorFadeTo.blue  ( ) );
     pTemp  = pShadowItem->setSibling ( (MenuObject *)this, pTemp, tr ( "Fading" ), qsArgs );
 
@@ -420,8 +422,8 @@ StructureItem *ShadowObject::createStructure ( StructureItem *pParentItem )
       delete pShadowItem->lastChild ( );
     }
     qsArgs = tr ("color(%1, %2, %3)").
-		      arg ( m_color.red   ( ) ).
-		      arg ( m_color.green ( ) ).
+                      arg ( m_color.red   ( ) ).
+                      arg ( m_color.green ( ) ).
                       arg ( m_color.blue  ( ) );
     pTemp  = pShadowItem->setSibling ( this, pTemp, tr ( "Shadow Color" ), qsArgs );
   }
@@ -1301,7 +1303,7 @@ void ShadowObject::setColorFading ( QColor theColor, float fFading )
 MenuObject *ShadowObject::clone ( QWidget *pParentWidget, MenuObject *pMenuObject )
 {
   if ( ! pParentWidget )
-    pParentWidget = MenuObject::parent ( );
+         pParentWidget =  MenuObject::parent ( );
   ShadowObject *pNewObject = new ShadowObject( pMenuObject, pParentWidget );
   pNewObject->setType         ( type         ( ) );
   pNewObject->setTransparency ( transparency ( ) );
@@ -1315,9 +1317,9 @@ MenuObject *ShadowObject::clone ( QWidget *pParentWidget, MenuObject *pMenuObjec
 
   // The following two are not really needed, since we get those
   // informations solely from the Normal State - objects ...
-  pNewObject->setRect(rect());
-  pNewObject->setModifiers(*modifiers());
-  
+  pNewObject->setRect      (  rect      ( ) );
+  pNewObject->setModifiers ( *modifiers ( ) );
+
   return pNewObject;
 }
 
