@@ -514,7 +514,6 @@ void SourceToolBar::slotTranscodeAll()
   updateEntryHeader ( pSourceFileEntry );
 }
 
-
 void SourceToolBar::slotTranscodeNone ( )
 {
   uint t;
@@ -534,7 +533,7 @@ void SourceToolBar::slotTranscodeNone ( )
       break;
     }
   }
-  
+
   if ( ! pSourceFileEntry )
     return; // Could not find the currently selected SourceFileEntry
 
@@ -554,7 +553,7 @@ void SourceToolBar::slotTranscodeNone ( )
 	  QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No )
       return;
   }
-  
+
   for ( t=0; t<pSourceFileEntry->listFileInfos.count ( ); t++ )  {
     pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
     if ( ! pSourceFileInfo ) // error
@@ -709,7 +708,7 @@ void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
     return;
   uint t;
   QFileInfo fileInfo (listAddMovies[0]);
-  QString qsPath = fileInfo.filePath();
+  QString qsPath = fileInfo.dirPath ( TRUE );
   Global::qsCurrentPath = qsPath;
 
   QCursor myCursor (QCursor::WaitCursor);
@@ -1157,7 +1156,7 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 	QFileInfo fileInfo ( listSoundNames[0] );
 
 	// And here we set the  current Directory for the application ...
-	QString qsPath = fileInfo.filePath ( );
+	QString qsPath = fileInfo.dirPath ( TRUE );
 	Global::qsCurrentPath = qsPath;
 
 	// Before we insert it we should remove all previous entries so that we hold only one entry for one sound file
@@ -1206,7 +1205,8 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 	// this new sound is assigned to the current DVDMenu's Preview. Phew what a long list to get there ...
 	DVDMenu *pCurrentSubMenu = m_pDVDAuthor->getCurrentSubMenu();
 	if ( pCurrentSubMenu )
-	  pCurrentSubMenu->getMenuPreview()->undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::NEW_AUDIO, pEntry ));	// And finally we add it to the list ...
+	     pCurrentSubMenu->getMenuPreview ( )->undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::NEW_AUDIO, pEntry ));	// And finally we add it to the list ...
+
 	new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
 
 	// And further on to the m_pListViewVideoSources ...
@@ -1307,7 +1307,7 @@ void SourceToolBar::updateSlideshowItem ( SourceFileEntry *pEntry )
   if ( pInfo->qsVideoFormat.find ( "pal", 0, FALSE ) > -1 )
        bPal = true;
 
-  iLength = (unsigned int) ( 1000 * ( pXmlSlideshow->countImg ( ) * pXmlSlideshow->filter_delay + (pXmlSlideshow->countImg ( )+1) * pXmlSlideshow->delay ) );
+  iLength = 1000 * pXmlSlideshow->slideLength ( );// (unsigned int) ( 1000 * ( pXmlSlideshow->countImg ( ) * pXmlSlideshow->filter_delay + (pXmlSlideshow->countImg ( )+1) * pXmlSlideshow->delay ) );
   for ( t=0; t<pXmlSlideshow->countVid ( ); t++ )  {
     pXmlVid  = pXmlSlideshow->getVid  ( t );
     if ( pXmlVid )
@@ -1315,6 +1315,9 @@ void SourceToolBar::updateSlideshowItem ( SourceFileEntry *pEntry )
   }
   pInfo->qsLength = theUtils.getStringFromMs ( iLength );
 
+CXmlSlideshow *p = pXmlSlideshow;
+printf ( "%s::%d > <%s> audio<%d> bckg<%s>\n", __FILE__, __LINE__, p->slideshow_name.ascii ( ), (int)p->audio_list.count ( ), p->background.ascii ( ) );
+
   fileInfo.setFile ( pInfo->qsFileName );
   qsInfo = QString ( fileInfo.fileName ( ) + QString ( "\n" ) + pInfo->qsLength );
 
