@@ -71,7 +71,7 @@ Subtitles::Subtitles ()
   m_bTextSubtitles  = false; // default to image based subtitles (render subtitles in this class)
   m_iTextFontSize   = 24;
   m_qsTextFont      = "Vera";
-  m_alignment       = QPoint ( 1, 3 ); // HAlign=Center / VAlign=top
+  m_alignment       = QPoint ( 1, 4 ); // HAlign=Center / VAlign=top
   m_subtitleState   = STATE_MANUAL;
   m_rect            = QRect ( 0, 0, 720, 480 ); // standard NTSC res.
 }
@@ -195,7 +195,7 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
     }
   }
 
-  infoNode = theElement.firstChild ();  
+  infoNode = theElement.firstChild ();
   while (!infoNode.isNull())	{
     infoElement = infoNode.toElement();
     // Okay, here we read the stored data from the xml file.
@@ -649,6 +649,7 @@ void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo,
   QFileInfo  fileInfo   ( pInfo->qsFileName );
   Subtitles *pSubtitles = NULL;
   QString    qsLang, qsXmlFile;
+  QRect      rect;
   Utils      theUtils;
   int        t, iFirstNewSubtitleNumber = 0;
   bool       bOkay;
@@ -659,8 +660,8 @@ void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo,
     pSubtitles = pInfo->arraySubtitles [ t ];
     if ( pSubtitles ) { 
       if ( ( pSubtitles->m_subtitleState == Subtitles::STATE_META_INFO  ) ||
-	   ( pSubtitles->m_subtitleState == Subtitles::STATE_EXTRACTING )  )
-	return;
+           ( pSubtitles->m_subtitleState == Subtitles::STATE_EXTRACTING )  )
+             return;
     }
   }
   // lastly we see if we can extract the MetaInfo ( DV only at this time )
@@ -675,14 +676,17 @@ void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo,
   }
 
   // Next we should import the subtitles ...
+  rect = QRect ( 0, 0, 720, 480 ); // standard NTSC res.
   fFPS =  pInfo->qsFPS.toFloat ( &bOkay );
   if ( ( ! bOkay ) || ( fFPS < 19.0f ) ) {
     fFPS = 29.97f;
-    if ( pInfo->qsVideoFormat.upper ( ) == "PAL" )
+    if ( pInfo->qsVideoFormat.upper ( ) == "PAL" )  {
       fFPS = 25.0f;
+      rect = QRect ( 0, 0, 720, 576 );
+    }
   }
 
-  //	sanityCheckSubtitleTrack ( iFirstNewSubtitleNumber );
+  // sanityCheckSubtitleTrack ( iFirstNewSubtitleNumber );
   if ( ( qsIso639.isEmpty ( ) ) || ( qsIso639.length ( ) != 2 ) ) 
     qsIso639 = "en";
   qsLang = theUtils.iso639 ( qsIso639, false );
@@ -697,11 +701,11 @@ void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo,
   pSubtitles->m_iSubtitleNumber     = iFirstNewSubtitleNumber;
   pSubtitles->m_qsIso639            = qsIso639;
   pSubtitles->m_qsXmlFile           = qsXmlFile;
-  pSubtitles->m_subColors[0]        = Rgba (   0,   0,  0, 0 ); // black background
-  pSubtitles->m_subColors[1]        = Rgba ( 250, 250, 10, 0 ); // Yellow font color
+  pSubtitles->m_subColors[0]        = Rgba (   0,   0,  0, 255 ); // black background
+  pSubtitles->m_subColors[1]        = Rgba ( 250, 250, 10, 255 ); // Yellow font color
   pSubtitles->m_iOutline            = 2;
-  pSubtitles->m_font.fromString ( "Sans Serif,24,-1,5,50,0,0,0,0,0" );
-
+  pSubtitles->m_rect                = rect;
+  pSubtitles->m_font.fromString ( "Sans Serif,24,-1,5,75,0,0,0,0,0" );
   // link it with the SourceFileInfo ...
   if ( pInfo->arraySubtitles[ iFirstNewSubtitleNumber ] )
     delete pInfo->arraySubtitles[ iFirstNewSubtitleNumber ];
