@@ -582,7 +582,7 @@ void TemplateWizard::slotTemplateClicked (QMouseEvent *pMouseEvent)
   QFileInfo backgroundInfo (qsFileName);
   MediaInfo *pMediaInfo = Global::pApp->getMediaInfo ( );
 
-  Global::qsCurrentPath = backgroundInfo.absFilePath ( );
+  Global::qsCurrentPath = backgroundInfo.dirPath ( TRUE );
 
   pDropZone->qsFileName = qsFileName;
   qsExtensions = pMediaInfo->getExtensions (true);
