@@ -1,7 +1,11 @@
 /****************************************************************************
 ** UndoBuffer and UndoObject code
-** Created: Thursday Jan 2'nd 2003
-** Varol Okan
+**
+**   Created : Thursday Jan 2'nd 2003
+**        by : Varol Okan
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 ****************************************************************************/
 #include "undobuffer.h"
 
@@ -109,6 +113,7 @@ UndoBuffer::pushRedo (UndoObject *pUndoObject)
 //////////////////////////////////////////////////////////////////////
 UndoObject::UndoObject()
 {
+  m_enUndoType = -1; 
 }
 
 UndoObject::~UndoObject()
