@@ -12,9 +12,9 @@
 ****************************************************************************/
 
 #include <stdlib.h>
-#ifdef QDVD_LINUX 
+#ifdef QDVD_LINUX
 #include <unistd.h>
-#endif 
+#endif
 
 #include <qfileinfo.h>
 #include <qimage.h>
@@ -153,17 +153,17 @@ QRgb Utils::nearestColor (QRgb *rgbPalette, int iNumColors, QRgb rgbSeeking)
   QRgb rgbReturn = rgbPalette[0];
   int t, iRed, iGreen, iBlue, r, g, b;
   unsigned long iSquare, iClosestColor = 0x1ff*0x1ff*3+1;
-  
+
   r = qRed   (rgbSeeking) - 255;
   g = qGreen (rgbSeeking) - 255;
   b = qBlue  (rgbSeeking) - 255;
-  
+
   for (t=0;t<iNumColors;t++)	{
     iRed    = qRed   (rgbPalette[t]) - r;
     iGreen  = qGreen (rgbPalette[t]) - g;
     iBlue   = qBlue  (rgbPalette[t]) - b;
     iSquare = iRed*iRed + iGreen*iGreen + iBlue*iBlue;
-    
+
     // Now let us check if we found a color closer then the previous one.
     if (   iSquare  < iClosestColor   )  {
       rgbReturn     = rgbPalette[t];
@@ -179,17 +179,17 @@ QRgb Utils::nearestColor (QRgb *rgbPalette, int iNumColors, QRgb rgbSeeking)
   QRgb rgbReturn = rgbPalette[0];
   int t, iRed, iGreen, iBlue, r, g, b;
   unsigned long iSquare, iClosestColor = 0xff*0xff*3+1;
-  
+
   r = qRed   (rgbSeeking);
   g = qGreen (rgbSeeking);
   b = qBlue  (rgbSeeking);
-  
+
   for (t=0;t<iNumColors;t++)	{
     iRed    = qRed   (rgbPalette[t]) - r;
     iGreen  = qGreen (rgbPalette[t]) - g;
     iBlue   = qBlue  (rgbPalette[t]) - b;
     iSquare = iRed*iRed + iGreen*iGreen + iBlue*iBlue;
-    
+
     // Now let us check if we found a color closer then the previous one.
     if (   iSquare  < iClosestColor   )  {
       rgbReturn     = rgbPalette[t];
@@ -613,22 +613,26 @@ QStringList Utils::getProjectsFromTempPath()
 	// under the temp path
 	uint t;
 	QStringList listOfProjects;
+	QString qsTemp;
 	QDir mainMenuDir, tempDir (Global::qsTempPath);
 	QFile backgroundFile, menuBackgroundFile;
 	
 	// But we aree only interested in sub dirs ...
 	tempDir.setFilter (QDir::Dirs);
 	for (t=0;t<tempDir.count();t++)	{
-		// three criterias 
-		backgroundFile.setName(tempDir.absPath() + QString ("/%1/Main Menu VMGM/background.jpg").arg(tempDir[t]));
-		menuBackgroundFile.setName(tempDir.absPath() + QString ("/%1/background.jpg").arg(tempDir[t]));
-		mainMenuDir.setPath (tempDir.absPath() + QString ("/%1/Main Menu VMGM").arg(tempDir[t]));
-		if (backgroundFile.exists ())
-			listOfProjects.append (tempDir[t]);
-		else if (menuBackgroundFile.exists ())
-			listOfProjects.append (tempDir[t]);
-		else if (mainMenuDir.exists ())
-			listOfProjects.append (tempDir[t]);
+		qsTemp = tempDir[t];
+		if ( ( qsTemp == "." ) || ( qsTemp == ".." ) )
+			continue;
+		// three criterias
+		backgroundFile.setName ( tempDir.absPath ( ) + QString ( "/%1/Main Menu VMGM/background.jpg" ).arg ( qsTemp ) );
+		menuBackgroundFile.setName ( tempDir.absPath ( ) + QString ("/%1/background.jpg" ).arg ( qsTemp ) );
+		mainMenuDir.setPath ( tempDir.absPath ( ) + QString ( "/%1/Main Menu VMGM" ).arg ( qsTemp ) );
+		if ( backgroundFile.exists ( ) )
+			listOfProjects.append ( qsTemp );
+		else if (menuBackgroundFile.exists ( ) )
+			listOfProjects.append ( qsTemp );
+		else if (mainMenuDir.exists ( ) )
+			listOfProjects.append ( qsTemp );
 	}
 	return listOfProjects;
 }
@@ -862,58 +866,54 @@ bool Utils::hasVobus ( QString qsFileName )
     Navigation packets are PES packets with a stream id 0xbf, i.e.
     private stream 2.  It's made up of PCI, Presentation Control Information
     and DSI, Data Search Information.
-    
+
     details: www.mpucoder.com
    */
-  
+
   unsigned char PCI_PACK[] = { 0x00, 0x00, 0x01, 0xBF, 0x03, 0xD4 };
   unsigned char DSI_PACK[] = { 0x00, 0x00, 0x01, 0xBF, 0x03, 0xFA };
-  
+
   QFile theFile ( qsFileName );
   if ( ! theFile.open ( IO_ReadOnly ) )
     return false;
-  
+
   // skip zeroes at start of file
   int zeroCnt = 0;
   char c;
   while ( (c = (char)theFile.getch ( ) ) == 0)
     zeroCnt++;
-  
-  if (zeroCnt < 2 || c != 1) 
+
+  if ( zeroCnt < 2 || c != 1 )
     return false;
- 
-  const long MAX_LENGTH=16384; // only looking at 1st 16KB - enough to contain nav packs
+
+  const long MAX_LENGTH = 16*1024; // only looking at 1st 16KB - enough to contain nav packs
   unsigned char *buffer = new unsigned char[MAX_LENGTH];
 
   buffer[0] = buffer[1] = 0; buffer[2] = 1;
   int iRead = theFile.readBlock ( (char *)(buffer+3), MAX_LENGTH-3);
-  
-  bool valid_pci = false;
-  bool valid_dsi = false;
-  for (int i=0; i<iRead-(int)sizeof(PCI_PACK); i++)
-    {
-      int j;
-      for (j=0; j<(int)sizeof(PCI_PACK); j++)
-	{
-	  if(buffer[i+j] != PCI_PACK[j])
-	    break;
-	  else if (j == sizeof(PCI_PACK)-1)
-	    valid_pci=true;
-	}
-      for (j=0; j<(int)sizeof(DSI_PACK); j++)
-      {
-	if(buffer[i+j] != DSI_PACK[j])
-	  break;
-	else if (j == sizeof(DSI_PACK)-1)
-	  valid_dsi=true;
-      }
-      
-      if (valid_pci && valid_dsi) {
-		delete []buffer;
-        return true;
-	  }
+
+  bool bValidPCI = false;
+  bool bValidDSI = false;
+  for ( int i=0; i<iRead-(int)sizeof(PCI_PACK); i++ )  {
+    int j;
+    for ( j=0; j<(int)sizeof(PCI_PACK); j++ )  {
+      if ( buffer[i+j] != PCI_PACK[j] )
+        break;
+      else if ( j == sizeof(PCI_PACK) - 1 )
+        bValidPCI  = true;
     }
-  
+    for ( j=0; j<(int)sizeof(DSI_PACK); j++ )  {
+      if ( buffer[i+j] != DSI_PACK[j] )
+        break;
+      else if (j == sizeof(DSI_PACK)-1)
+        bValidDSI = true;
+    }
+    if ( bValidPCI && bValidDSI )  {
+      delete []buffer;
+      return true;
+    }
+  }
+  delete []buffer;
   return false;
 }
 
@@ -921,9 +921,14 @@ bool Utils::checkCommand ( const char *pCommand )
 {
   // executes a command and checks if there was a result
   int iRet = 0;
-  QString qsCommand = QString ( "%1 > /tmp/test " ).arg ( pCommand );
+  char tmpName[11] =  { "out_XXXXXX" };
+  int iFD = mkstemp ( (char *)&tmpName );
+  iFD = iFD; // Silence the compiler warnings.
+  QString qsTmpFile = QString ( "/tmp/%1"  ).arg ( tmpName  );
+  QString qsCommand = QString ( "%1 > %2 " ).arg ( pCommand ).arg ( qsTmpFile );
+
   iRet = system ( qsCommand.ascii ( ) );
-  QFile theFile ( "/tmp/test" );
+  QFile theFile ( qsTmpFile );
   if ( theFile.exists ( ) ) {
     if ( theFile.size ( ) > 2 )
       return true;
