@@ -21,7 +21,7 @@
 // Version 1.1 RC3 = 1. 01 03
 // Note the minor version is one behind the RC version
 #define QDVDAUTHOR_VERSION                     "XMLVersion"
-#define QDVDAUTHOR_VERSION_NUMBER              "1.0700"
+#define QDVDAUTHOR_VERSION_NUMBER              "1.0800"
 
 // Here we goof around with the Templates
 // Nodes
@@ -56,6 +56,7 @@
 #define DVDAUTHOR_ROOT_MENU                     "DVDMenu"
 #define DVDAUTHOR_MENU                          "MenuVariables"
 #define DVDAUTHOR_PREVIEW                       "PreviewVariables"
+#define DVDAUTHOR_DVDLAYOUT                     "DVDLayout"
 
 // Here are the defines for teh DVDMenu - Interface.
 //#define DVD_MENU                                "DVDMenu"
@@ -283,6 +284,13 @@
 #define MANIPULATOR_COLOR                       "Color"
 #define MANIPULATOR_DELTA                       "Delta"
 
+// Vars for the DVDLayout tab
+#define LAYOUT_ZOOM                             "Zoom"
+#define LAYOUT_GRID                             "Grid"
+#define LAYOUT_TYPE                             "Type"
+#define LAYOUT_CONTAINER                        "Container"
+#define LAYOUT_OBJECT_RECT                      "Rect"
+
 // QRect variables ...
 #define RECT_X                                  "X"
 #define RECT_Y                                  "Y"
