@@ -86,37 +86,36 @@ bool CXmlDVDAuthor::readXml (QString &fileName )
 	return bReturn;
 }
 
-bool CXmlDVDAuthor::dvdauthor_struct::readXml(QDomElement *pDocElem)
+bool CXmlDVDAuthor::dvdauthor_struct::readXml ( QDomElement *pDocElem )
 {
-	titleset_struct *pTempTitleset = new titleset_struct;	// temp to get the node_name.
+	titleset_struct  tempTitleset;  // temp to get the node_name.
 	titleset_struct *pTitleset = NULL;
 	bool bReturn = true;
 	debug_out ("CXmlDVDAuthor::dvdauthor_struct::readXml <%s><%s>\n",(const char *)pDocElem->tagName(), (const char *)node_name);
-	if (pDocElem->tagName() != node_name)
+	if ( pDocElem->tagName ( ) != node_name )
 		return false;
 	// So lets get first the attributes for this node.
 	QDomAttr a = pDocElem->attributeNode ( DVDAUTHOR_DEST );
-	dest = a.value();
+	dest = a.value ( );
 	a = pDocElem->attributeNode ( DVDAUTHOR_JUMPPAD );
-	jumppad = a.value();
+	jumppad = a.value ( );
 
 	// And now read in all remaining nodes and handle them accordingly.
-	QDomNode xmlNode = pDocElem->firstChild();
-	while( !xmlNode.isNull() ) {
-		QDomElement searchTree = xmlNode.toElement();
-		if (searchTree.tagName() == vmgm.node_name)
-			bReturn = vmgm.readXml(&searchTree);
-		else if (searchTree.tagName() == pTempTitleset->node_name)	{
-			pTitleset = addTitleset();
-			bReturn = pTitleset->readXml(&searchTree);
+	QDomNode xmlNode = pDocElem->firstChild ( );
+	while ( !xmlNode.isNull ( ) )  {
+		QDomElement searchTree = xmlNode.toElement  ( );
+		if ( searchTree.tagName ( ) == vmgm.node_name )
+			bReturn = vmgm.readXml  ( &searchTree );
+		else if ( searchTree.tagName ( ) == tempTitleset.node_name )  {
+			pTitleset = addTitleset ( );
+			bReturn   = pTitleset->readXml ( &searchTree );
 		}
 		// If there has been a problem then return false.
-		if (!bReturn)
+		if ( ! bReturn )
 			return false;
 		// Otherwise go to the next node ...
-		xmlNode = xmlNode.nextSibling();
+		xmlNode = xmlNode.nextSibling ( );
 	}
-	delete pTempTitleset;
 	return true;
 }
 
@@ -633,23 +632,31 @@ bool CXmlDVDAuthor::writeXml (QString &fileName)
 	if (!projectFile.open(IO_WriteOnly))
 		return false;
 
-	QString xml = xmlDoc.toString();
+	QString xml = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
+	xml += xmlDoc.toString ( );
 	// QDomDocument converts '<' to "&lt;", So if we want comments in
 	// the generated file, we should replace them here.
 	xml.replace ( "&lt;", "<"); 
 	debug_out ("%s\n", (const char *)xml);
-	projectFile.writeBlock(xml, qstrlen (xml));
+	xml = xml.utf8 ( );
+	projectFile.writeBlock ( xml, qstrlen ( xml ) );
 
 	projectFile.close();
 	return true;
 }
 
-bool CXmlDVDAuthor::dvdauthor_struct::writeXml(QDomDocument *pDocument, QDomElement *)
+bool CXmlDVDAuthor::dvdauthor_struct::writeXml ( QDomDocument *pDocument, QDomElement * )
 {
 	debug_out ("CXmlDVDAuthor::dvdauthor_struct::writeXml <%s>\n", (const char *)node_name);
 	bool bReturn = true;
 	int t = 0;
-	QDomElement rootDVDAuthor = pDocument->createElement( node_name );	// <dvdauthor>
+	QDomElement rootDVDAuthor = pDocument->createElement ( node_name ); // <dvdauthor>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		rootDVDAuthor.appendChild ( domComment );
+	}
+
 	// Here we set the attributes of the <dvdauthor> tag
 	if (!dest.isNull())
 		rootDVDAuthor.setAttribute( DVDAUTHOR_DEST, dest );
@@ -676,6 +683,11 @@ bool CXmlDVDAuthor::vmgm_struct::writeXml(QDomDocument *pDocument, QDomElement *
 	int t = 0;
 
 	QDomElement vmgmNode = pDocument->createElement( node_name );	// <vmm>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		vmgmNode.appendChild ( domComment );
+	}
 	// And now proceed to writing the rest of the file.
 	pNodeElement->appendChild( vmgmNode );
 
@@ -697,6 +709,11 @@ bool CXmlDVDAuthor::titleset_struct::writeXml(QDomDocument *pDocument, QDomEleme
 	bool bReturn = true;
 	int t = 0;
 	QDomElement titlesetNode = pDocument->createElement( node_name );	// <titleset>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		titlesetNode.appendChild ( domComment );
+	}
 	// And now proceed to writing the rest of the file.
 	pNodeElement->appendChild( titlesetNode );
 	t = 0;
@@ -727,6 +744,11 @@ bool CXmlDVDAuthor::menus_struct::writeXml(QDomDocument *pDocument, QDomElement
 	int t = 0;
 	QDomElement menusNode = pDocument->createElement( node_name );	// <menus>
 	// Here we set the attributes of the <dvdauthor> tag
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		menusNode.appendChild ( domComment );
+	}
 	if (!lang.isNull())
 		menusNode.setAttribute( MENUS_LANG, lang );
 
@@ -765,6 +787,11 @@ bool CXmlDVDAuthor::video_struct::writeXml(QDomDocument *pDocument, QDomElement
 	debug_out ("CXmlDVDAuthor::video_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 
 	QDomElement videoNode = pDocument->createElement( node_name );	// <video>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		videoNode.appendChild ( domComment );
+	}
 	// Here we set the attributes of the <dvdauthor> tag
 	if (!format.isNull())
 		videoNode.setAttribute( VIDEO_FORMAT, format );
@@ -789,6 +816,11 @@ bool CXmlDVDAuthor::audio_struct::writeXml(QDomDocument *pDocument, QDomElement
 	debug_out ("CXmlDVDAuthor::audio_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 
 	QDomElement audioNode = pDocument->createElement( node_name );	// <audio>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		audioNode.appendChild ( domComment );
+	}
 	// Here we set the attributes of the <dvdauthor> tag
 	if (!format.isNull())
 		audioNode.setAttribute( AUDIO_FORMAT, format );
@@ -813,6 +845,11 @@ bool CXmlDVDAuthor::subpicture_struct::writeXml(QDomDocument *pDocument, QDomEle
 		return true;
 	debug_out ("CXmlDVDAuthor::subpicture_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement subpictureNode = pDocument->createElement( node_name );	// <dvdauthor>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		subpictureNode.appendChild ( domComment );
+	}
 	// Here we set the attributes of the <dvdauthor> tag
 	if (!lang.isNull())
 		subpictureNode.setAttribute( SUBPICTURE_LANG, lang );
@@ -828,6 +865,11 @@ bool CXmlDVDAuthor::titles_struct::writeXml(QDomDocument *pDocument, QDomElement
 	bool bReturn = true;
 	int t = 0;
 	QDomElement titlesNode = pDocument->createElement( node_name );	// <titles>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		titlesNode.appendChild ( domComment );
+	}
 	// And now proceed to writing the rest of the file.
 	pNodeElement->appendChild( titlesNode );
 	bReturn = video.writeXml (pDocument, &titlesNode);
@@ -861,6 +903,11 @@ bool CXmlDVDAuthor::pgc_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	bool bReturn = true;
 	int t = 0;
 	QDomElement pgcNode = pDocument->createElement( node_name );	// <pgc>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		pgcNode.appendChild ( domComment );
+	}
 	// Here we set the attributes of the <dvdauthor> tag
 	if (!entry.isNull())
 		pgcNode.setAttribute( PGC_ENTRY, entry );
@@ -901,6 +948,11 @@ bool CXmlDVDAuthor::button_struct::writeXml(QDomDocument *pDocument, QDomElement
 		return true;
 	debug_out ("CXmlDVDAuthor::button_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement buttonNode = pDocument->createElement( node_name );	// <button>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		buttonNode.appendChild ( domComment );
+	}
 	// And now proceed to writing the rest of the file.
 	pNodeElement->appendChild( buttonNode );
 	// Here we set the attributes of the <button> tag
@@ -918,6 +970,11 @@ bool CXmlDVDAuthor::cell_struct::writeXml(QDomDocument *pDocument, QDomElement *
 		return true;
 	debug_out ("CXmlDVDAuthor::cell_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement cellNode = pDocument->createElement( node_name );	// <cell>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		cellNode.appendChild ( domComment );
+	}
 	// Here we set the attributes of the <dvdauthor> tag
 	if (!start.isNull())
 		cellNode.setAttribute( CELL_START, start );
@@ -938,6 +995,11 @@ bool CXmlDVDAuthor::vob_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 {
 	debug_out ("CXmlDVDAuthor::vob_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement vobNode = pDocument->createElement( node_name );	// <vob>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		vobNode.appendChild ( domComment );
+	}
 	// Here we set the attributes of the <dvdauthor> tag
 	if (!file.isNull())
 		vobNode.setAttribute( VOB_FILE, file );
@@ -957,6 +1019,11 @@ bool CXmlDVDAuthor::fpc_struct::writeXml ( QDomDocument *pDocument, QDomElement
 		return true;
 	debug_out ("CXmlDVDAuthor::fpc_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement fpcNode = pDocument->createElement ( node_name );	// <fpc>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		fpcNode.appendChild ( domComment );
+	}
 	// And now proceed to writing the rest of the file.
 	pNodeElement->appendChild ( fpcNode );
 	QDomText domText = pDocument->createTextNode ( value );
@@ -971,6 +1038,11 @@ bool CXmlDVDAuthor::pre_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	  return true;
 	debug_out ("CXmlDVDAuthor::pre_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement preNode = pDocument->createElement( node_name );	// <pre>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		preNode.appendChild ( domComment );
+	}
 	// And now proceed to writing the rest of the file.
 	pNodeElement->appendChild( preNode );
 	QDomText domText = pDocument->createTextNode (value);
@@ -985,6 +1057,11 @@ bool CXmlDVDAuthor::post_struct::writeXml(QDomDocument *pDocument, QDomElement *
 	  return true;
 	debug_out ("CXmlDVDAuthor::post_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement postNode = pDocument->createElement( node_name );	// <post>
+	if ( ! comment.isEmpty ( ) )  {
+		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QDomText domComment = pDocument->createTextNode ( qsComment );
+		postNode.appendChild ( domComment );
+	}
 	// And now proceed to writing the rest of the file.
 	QDomText domText = pDocument->createTextNode (value);
 	postNode.appendChild( domText );
@@ -1055,21 +1132,23 @@ bool CXmlSpumux::writeXml ()
 	return writeXml(fileName);
 }
 
-bool CXmlSpumux::writeXml (QString &fileName)
+bool CXmlSpumux::writeXml ( QString &fileName )
 {
-	debug_out ("CXmlSpumux::writeXml (%s)\n",(const char *)fileName);
+	debug_out ( "CXmlSpumux::writeXml (%s)\n",(const char *)fileName );
 	// Assign the file
-	QFile projectFile(fileName);
-	if (!projectFile.open(IO_WriteOnly))
+	QFile  projectFile ( fileName );
+	if ( ! projectFile.open ( IO_WriteOnly ) )
 		return false;
 
 	QDomDocument xmlDoc( DVD_DOCTYPE );	// <""> for now.
 	bool bRet = m_subpictures.writeXml (&xmlDoc);
 	if (bRet)	{
-		QString xml = xmlDoc.toString();
-		xml.replace ( "&lt;", "<"); 
-		debug_out ("%s\n", (const char *)xml);
-		projectFile.writeBlock(xml, qstrlen (xml));
+		QString xml = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
+		xml += xmlDoc.toString (    );
+		xml.replace    ( "&lt;", "<"); 
+		debug_out      ("%s\n", (const char *)xml );
+		xml = xml.utf8 ( );
+		projectFile.writeBlock ( xml, qstrlen ( xml ) );
 	}
 
 	projectFile.close();
@@ -1714,6 +1793,15 @@ CXmlDVDAuthor::vob_struct *CXmlDVDAuthor::pgc_struct::addVob ()
 	return ppArrayVob[i];
 }
 
+int CXmlDVDAuthor::titles_struct::pgcCount ( )
+{
+	int t=0;
+	if ( ! ppArrayPgc )
+		return 0;
+	while ( ppArrayPgc[t] ) t++;
+	return t;
+}
+
 CXmlDVDAuthor::pgc_struct *CXmlDVDAuthor::titles_struct::addPgc ()
 {
 	// This function simply enlarges the array of available titlesets.
