@@ -16,47 +16,47 @@
 #include <qstring.h>
 #include <qdom.h>
 
-#define DVD_DOCTYPE			""
+#define DVD_DOCTYPE              ""
 // Here we define all attributes for the structures.
-#define DVDAUTHOR_DEST		 "dest"
-#define DVDAUTHOR_JUMPPAD	 "jumppad"
-#define MENUS_LANG		 "lang"
-#define VIDEO_FORMAT		 "format"
-#define VIDEO_ASPECT		 "aspect"
-#define VIDEO_RESOLUTION	 "resolution"
-#define VIDEO_CAPTION		 "caption"
-#define VIDEO_WIDESCREEN	 "widescreen"
-#define AUDIO_FORMAT		 "format"
-#define AUDIO_CHANNELS		 "channels"
-#define AUDIO_QUANT		 "quant"
-#define AUDIO_DOLBY		 "dolby"
-#define AUDIO_LANG		 "lang"
-#define SUBPICTURE_LANG		 "lang"
-#define PGC_ENTRY		 "entry"
-#define PGC_PALETTE		 "palette"
-#define PGC_PAUSE		 "pause"
-#define BUTTON_NAME		 "name"
-#define VOB_FILE		 "file"
-#define VOB_CHAPTERS		 "chapters"
-#define VOB_PAUSE		 "pause"
-#define CELL_START		 "start"
-#define CELL_END		 "end"
-#define CELL_CHAPTER		 "chapter"
-#define CELL_PROGRAM		 "program"
-#define CELL_PAUSE		 "pause"
+#define DVDAUTHOR_DEST           "dest"
+#define DVDAUTHOR_JUMPPAD        "jumppad"
+#define MENUS_LANG               "lang"
+#define VIDEO_FORMAT             "format"
+#define VIDEO_ASPECT             "aspect"
+#define VIDEO_RESOLUTION         "resolution"
+#define VIDEO_CAPTION            "caption"
+#define VIDEO_WIDESCREEN         "widescreen"
+#define AUDIO_FORMAT             "format"
+#define AUDIO_CHANNELS           "channels"
+#define AUDIO_QUANT              "quant"
+#define AUDIO_DOLBY              "dolby"
+#define AUDIO_LANG               "lang"
+#define SUBPICTURE_LANG          "lang"
+#define PGC_ENTRY                "entry"
+#define PGC_PALETTE              "palette"
+#define PGC_PAUSE                "pause"
+#define BUTTON_NAME              "name"
+#define VOB_FILE                 "file"
+#define VOB_CHAPTERS             "chapters"
+#define VOB_PAUSE                "pause"
+#define CELL_START               "start"
+#define CELL_END                 "end"
+#define CELL_CHAPTER             "chapter"
+#define CELL_PROGRAM             "program"
+#define CELL_PAUSE               "pause"
 // Here are the identifiers for spumux
-#define SPU_START		 "start"
-#define SPU_END			 "end"
-#define SPU_IMAGE		 "image"
-#define SPU_HIGHLIGHT		 "highlight"
-#define SPU_SELECT		 "select"
-#define SPU_TRANSPARENT		 "transparent"
-#define SPU_FORCE		 "force"
-#define SPU_AUTOOUTLINE		 "autooutline"
-#define SPU_OUTLINEWIDTH	 "outlinewidth"
-#define SPU_AUTOORDER		 "autoorder"
-#define SPU_XOFFSET		 "xoffset"
-#define SPU_YOFFSET		 "yoffset"
+#define SPU_START                "start"
+#define SPU_END                  "end"
+#define SPU_IMAGE                "image"
+#define SPU_HIGHLIGHT            "highlight"
+#define SPU_SELECT               "select"
+#define SPU_TRANSPARENT          "transparent"
+#define SPU_FORCE                "force"
+#define SPU_AUTOOUTLINE          "autooutline"
+#define SPU_OUTLINEWIDTH         "outlinewidth"
+#define SPU_AUTOORDER            "autoorder"
+#define SPU_XOFFSET              "xoffset"
+#define SPU_YOFFSET              "yoffset"
 #define TEXTSUB_FILENAME         "filename"
 #define TEXTSUB_CHARACTERSET     "characterset"
 #define TEXTSUB_FONT             "font"
@@ -72,17 +72,17 @@
 #define TEXTSUB_MOVIE_FPS        "movie-fps"
 #define TEXTSUB_MOVIE_WIDTH      "movie-width"
 #define TEXTSUB_MOVIE_HEIGHT     "movie-height"
-#define BUTTON_LABEL		 "name"
-#define BUTTON_X0		 "x0"
-#define BUTTON_Y0		 "y0"
-#define BUTTON_X1		 "x1"
-#define BUTTON_Y1		 "y1"
-#define BUTTON_UP		 "up"
-#define BUTTON_DOWN		 "down"
-#define BUTTON_LEFT	 	 "left"
-#define BUTTON_RIGHT		 "right"
-#define ACTION_LABEL		 "name"
-#define ACTION_LABEL_OLD	 "label"
+#define BUTTON_LABEL             "name"
+#define BUTTON_X0                "x0"
+#define BUTTON_Y0                "y0"
+#define BUTTON_X1                "x1"
+#define BUTTON_Y1                "y1"
+#define BUTTON_UP                "up"
+#define BUTTON_DOWN              "down"
+#define BUTTON_LEFT              "left"
+#define BUTTON_RIGHT             "right"
+#define ACTION_LABEL             "name"
+#define ACTION_LABEL_OLD         "label"
 
 class CXmlDVDAuthor
 {
@@ -95,6 +95,7 @@ private:
     virtual bool readXml  ( QDomElement * ) = 0;
     virtual bool writeXml ( QDomDocument *, QDomElement * ) = 0;
     QString node_name;	// Name of this node ...
+    QString comment;    // add "<!-- comment // -->"
   };
 public:
         class video_struct : public base_struct	{
@@ -234,6 +235,7 @@ public:
 		virtual bool readXml (QDomElement  *);
 		virtual bool writeXml(QDomDocument *, QDomElement *);
 		pgc_struct *addPgc ();
+		int pgcCount ( );
 
 		QString		titles;
 		video_struct	video;
@@ -267,27 +269,27 @@ public:
 	};
 	class dvdauthor_struct : public base_struct {
 		public:
-                          dvdauthor_struct   ();
-		 virtual ~dvdauthor_struct   ();
+                          dvdauthor_struct   ( );
+		 virtual ~dvdauthor_struct   ( );
 		// public functions ...
-		virtual bool readXml (QDomElement  *);
-		virtual bool writeXml(QDomDocument *, QDomElement *p=NULL);
-		titleset_struct *addTitleset ();
+		virtual bool readXml ( QDomElement  * );
+		virtual bool writeXml( QDomDocument *, QDomElement *p=NULL );
+		titleset_struct *addTitleset ( );
 		// dvdauthor attributes
-		QString dest;		// output dir
-		QString jumppad;	// [1|on|yes]
-		vmgm_struct	vmgm;
+		QString     dest;    // output dir
+		QString     jumppad; // [1|on|yes]
+		vmgm_struct vmgm;
 		titleset_struct	**ppArrayTitleset;
 	};
 public:
-	 CXmlDVDAuthor ();
-	~CXmlDVDAuthor ();
+	 CXmlDVDAuthor ( );
+	~CXmlDVDAuthor ( );
 
-	bool readXml  ();
-	bool readXml  (QString &fileName);
-	bool writeXml ();
-	bool writeXml (QString &fileName);
-	dvdauthor_struct *getDVDAuthor ();
+	bool readXml   ( );
+	bool readXml   ( QString &fileName );
+	bool writeXml  ( );
+	bool writeXml  ( QString &fileName );
+	dvdauthor_struct *getDVDAuthor   ( );
 
 private:
 	// Private functions
