@@ -60,4 +60,9 @@ QString &Encoder::getFileName   ( )
   return m_qsFileName;
 }
 
+void Encoder::setAudioList ( QStringList list )
+{
+  m_audioList = list;
+}
+
 }; // end of namespace Encoder
