@@ -275,6 +275,29 @@ void FFmpeg::Audio::closeStream ( )
   m_pResample = NULL;
 }
 
+FFmpeg::Buffer *FFmpeg::Audio::decode ( bool &bEOF )
+{
+  bEOF = false;
+  if ( ! m_pAudioCodecCtx )
+    return NULL;
+
+  AVPacket packet;
+  int iRet = -1;
+  while ( 1 )  {
+    iRet  = av_read_frame ( m_pFormatCtx, &packet );
+    if ( ( packet.size <=1 ) && ( iRet >= 0 ) )
+      continue;
+    break;
+  }
+
+  if ( iRet == 0 )
+    decode ( &packet  );
+  else  if ( iRet < 0 )
+    bEOF = true;
+
+  return m_pSampleBuffer;
+}
+/*
 FFmpeg::Buffer *FFmpeg::Audio::decode ( bool &bEOF )
 {
   bEOF = false;
@@ -290,7 +313,7 @@ FFmpeg::Buffer *FFmpeg::Audio::decode ( bool &bEOF )
 
   return m_pSampleBuffer;
 }
-
+*/
 FFmpeg::Buffer *FFmpeg::Audio::decode ( AVPacket *pPacket )
 {
   if ( ! pPacket )
@@ -309,6 +332,11 @@ FFmpeg::Buffer *FFmpeg::Audio::decode ( AVPacket *pPacket )
       memset ( pDecodedAudio, 0, m_iSampleSize );
 
       iLength = avcodec_decode_audio2 ( m_pAudioCodecCtx, pDecodedAudio, &iDecodedSize, pPacketData, iPacketSize );
+//printf ( "  %s::%d > len<%d> decoded<%d> iPacketSize<%d>\n", __FILE__, __LINE__, iLength, iDecodedSize, iPacketSize );
+
+      if ( iDecodedSize < 1 ) // Something completely strange happened ( E.g. ogg causes this )
+        continue;
+
       if ( iLength <= 0 )  {  // Error handling ...
         iPacketSize --;
         pPacketData ++;
@@ -344,8 +372,9 @@ FFmpeg::Buffer *FFmpeg::Audio::decode ( AVPacket *pPacket )
 
 FFmpeg::Buffer *FFmpeg::Audio::resample ( )
 {
-  if ( getSamplesPerChannel ( ) < 1 )
+  if ( getSamplesPerChannel ( ) < 1 )  {
     return m_pSampleBuffer;
+  }
 
   short *pResampled = (short *)av_malloc ( m_iSampleSize );
 
@@ -627,21 +656,21 @@ void FFmpeg::Vid::setSWScale ( int iTargetWidth, int iTargetHeight )
     printf ( "Could not allocate picture" );
 }
 
-AVFrame *FFmpeg::Vid::allocPicture ( uint8_t *&, int iPixFormat, int iWidth, int iHeight )
+AVFrame *FFmpeg::Vid::allocPicture ( uint8_t *&, PixelFormat pixFormat, int iWidth, int iHeight )
 {
   // Note: Might cause memory leak ? Should be invested at some point in time
   AVFrame *pFrame = avcodec_alloc_frame ( );
   if (  !  pFrame )
     return NULL;
 
-  int iSize = avpicture_get_size ( iPixFormat, iWidth, iHeight );
+  int iSize = avpicture_get_size ( pixFormat, iWidth, iHeight );
   uint8_t *pBuffer = (uint8_t *) av_malloc ( iSize );
   if (  !  pBuffer )  {
       av_free ( pFrame );
       return NULL;
   }
 
-  avpicture_fill ( (AVPicture *)pFrame, pBuffer, iPixFormat, iWidth, iHeight );
+  avpicture_fill ( (AVPicture *)pFrame, pBuffer, pixFormat, iWidth, iHeight );
   return pFrame;
 }
 
@@ -696,7 +725,7 @@ AVPacket *FFmpeg::Vid::getNextPacket ( AVStream *pOutputVideoStream, AVStream *p
   }
 
   // Here we adjust the frame rate in case the source has less frames ( E.g. 10 FPS ) then the required frames ( E.g. 29.97 )
-  if ( ( iReuseFrame > 1 ) && ( m_iVideoOutSize > 0 ) )  {
+  if ( ( iReuseFrame >= 1 ) && ( m_iVideoOutSize > 0 ) )  {
     m_iVideoOutSize = avcodec_encode_video ( pOutputVideoStream->codec, m_pVideoBuffer, VIDEO_BUF_SIZE, m_pFrame );
     if ( m_iVideoOutSize >= 0 )  {
       av_init_packet  ( m_pPacket );
@@ -745,7 +774,7 @@ AVPacket *FFmpeg::Vid::getNextPacket ( AVStream *pOutputVideoStream, AVStream *p
            iLen = avcodec_decode_video ( m_pVideoCodecCtx, pFrame, &iFrameFinished, m_pPacket->data, m_pPacket->size );
 
       // Did we get a video frame?
-      // Note : Instead of running the decoding again, it seems to be agreed on 
+      // Note : Instead of running the decoding again, it seems to be agreed on
       //        that simply ignoring the iFrameFinished check. However it works for me !
       if ( iFrameFinished )  {
         int iOutSize = -1;
@@ -1630,12 +1659,13 @@ bool FFmpeg::addVid ( QString qsFileName, int iTargetWidth, int iTargetHeight )
     //int  ret = av_interleaved_write_frame ( m_pOutputCtx, pPacket );
     int  ret = av_write_frame ( m_pOutputCtx, pPacket );
     if ( ret != 0 ) {
-      printf ( "Error while writing frame\n" );
+      closeVid  ( );
+      printf    ( "Error while writing frame\n" );
       return false;
     }
 
     if ( iAdjustFrameRate == 0 )  {
-         // Last frame was taken from the steam. Lets see if we have to insert
+         // Last frame was taken from the stream. Lets see if we have to insert
          // some extra frame to adjust the frame rate.
          if ( fTargetFrameRate  / fSourceFrameRate < 1.0 )
               fAdjustFrameRate -= fSourceFrameRate / fTargetFrameRate - 1.0; // E.g. 29.97 / 25 = NTSC to PAL = -0.2
@@ -1653,6 +1683,7 @@ bool FFmpeg::addVid ( QString qsFileName, int iTargetWidth, int iTargetHeight )
     // iAdjusFrame is decremented by one each time a frame is re-used
     // iAdjusrtFrame is set to 0 when a new frame is taken from the stream.
   }
+  closeVid ( );
   return true;
 }
 
