@@ -32,6 +32,12 @@
 #include <QList>
 #include <QMutex>
 
+#include <libavutil/avutil.h>
+
+#if ( LIBAVUTIL_VERSION_MAJOR >= 50 )
+#include <libavutil/pixfmt.h>
+#endif
+
 #include "../encoder.h"
 
 class QString;
@@ -44,6 +50,7 @@ struct AVPacket;
 struct AVStream;
 struct AVFrame;
 
+
 namespace Encoder
 {
 
@@ -134,8 +141,8 @@ class FFmpeg : public Encoder
 
     void        setSWScale  ( int, int );
     SwsContext *getSWScale  ( );
-    AVFrame   *allocPicture ( uint8_t *&, int,   int, int   );
-    AVPacket *getNextPacket ( AVStream *, AVStream *, int & );
+    AVFrame   *allocPicture ( uint8_t *&, PixelFormat, int, int   );
+    AVPacket *getNextPacket ( AVStream *, AVStream  *, int & );
 
   protected:
     int       reallySeek        ( AVFormatContext *, int, int64_t, int, double );
