@@ -560,12 +560,25 @@ void AnimationAttribute::append (long iFrame, QString qsValue)
 int main( int, char ** )
 {
 //    loadAnimationData ("test.anim");
-  	QRegExp rx ( "<[^>]*>"); //"s/</p>/HHH/g" );
-	QString qsFick, qsFuck ( "<p align=\"center\">FUCK THIS</p>" );
+  	QRegExp rx ( "\\{\\d*\\}.*\\{\\d*\\}.*" ); //( "{\\d*}{\\d*}.*" ); 
+	QString qsStart, qsStop, qsSubtitle, line ( "{24}{53}2005-06-24|15:48:30" );
+	rx.setMinimal ( TRUE );
 
-	qsFick = qsFuck.remove ( rx );
+    int cb1, cb2, cb3, cb4;
+	cb1 = line.find ( '{' );
+	cb2 = line.find ( '}' );
+    cb3 = line.find ( '{', cb2+1 );
+	cb4 = line.find ( '}', cb2+1 );
+	if ( ( cb1 < 0 ) || ( cb2 < 0 ) || ( cb3 < 0 ) || ( cb4 < 0 ) )
+	  printf ( "Fuckin' errrrror\n" );
+	else {
+      printf ( " I AM IN ! \n" );
+      qsStart = line.mid ( cb1+1, cb2-cb1-1 );
+	  qsStop  = line.mid ( cb3+1, cb4-cb3-1 );
+	  qsSubtitle= line.right ( line.length () - cb4 - 1 );
+    }
 
-	printf ( "%s  -  %s\n", qsFuck.ascii ( ), qsFick.ascii ( ) ) ;
+	printf ( "%s - %s - %s\n", qsStart.ascii ( ), qsStop.ascii ( ), qsSubtitle.ascii() ) ;
   
     return 0;
 }
